@@ -26,6 +26,7 @@
 	OCA.Talk = OCA.Talk || {};
 
 	var roomChannel = Backbone.Radio.channel('rooms');
+	var localMediaChannel = Backbone.Radio.channel('localMedia');
 
 	OCA.Talk.Application = Marionette.Application.extend({
 		OWNER: 1,
@@ -33,6 +34,13 @@
 		USER: 3,
 		GUEST: 4,
 		USERSELFJOINED: 5,
+		GUEST_MODERATOR: 6,
+
+		/* Must stay in sync with values in "lib/Participant.php". */
+		NOTIFY_DEFAULT: 0,
+		NOTIFY_ALWAYS: 1,
+		NOTIFY_MENTION: 2,
+		NOTIFY_NEVER: 3,
 
 		/* Must stay in sync with values in "lib/Room.php". */
 		FLAG_DISCONNECTED: 0,
@@ -40,6 +48,11 @@
 		FLAG_WITH_AUDIO: 2,
 		FLAG_WITH_VIDEO: 4,
 
+		/* Must stay in sync with values in "lib/Room.php". */
+		ROOM_TYPE_ONE_TO_ONE: 1,
+		ROOM_TYPE_GROUP: 2,
+		ROOM_TYPE_PUBLIC: 3,
+
 		/** @property {OCA.SpreedMe.Models.Room} activeRoom  */
 		activeRoom: null,
 
@@ -52,6 +65,9 @@
 		/** @property {OCA.Talk.Signaling.base} signaling  */
 		signaling: null,
 
+		/** property {String} selector */
+		mainCallElementSelector: '#app-content',
+
 		/** @property {OCA.SpreedMe.Models.RoomCollection} _rooms  */
 		_rooms: null,
 		/** @property {OCA.SpreedMe.Views.RoomListView} _roomsView  */
@@ -60,18 +76,10 @@
 		_participants: null,
 		/** @property {OCA.SpreedMe.Views.ParticipantView} _participantsView  */
 		_participantsView: null,
-		/** @property {boolean} videoWasEnabledAtLeastOnce  */
-		videoWasEnabledAtLeastOnce: false,
 		displayedGuestNameHint: false,
-		audioDisabled: localStorage.getItem("audioDisabled"),
-		audioNotFound: false,
-		videoDisabled: localStorage.getItem("videoDisabled"),
-		videoNotFound: false,
 		fullscreenDisabled: true,
 		_searchTerm: '',
 		guestNick: null,
-		_currentEmptyContent: null,
-		_lastEmptyContent: null,
 		_registerPageEvents: function() {
 			$('#select-participants').select2({
 				ajax: {
@@ -159,38 +167,27 @@
 				}
 			});
 
-			$('#select-participants').on("click", function() {
-				$('.select2-drop').find('.avatar[data-user]').each(function () {
-					var element = $(this);
-					if (element.data('user-display-name')) {
-						element.avatar(element.data('user'), 32, undefined, false, undefined, element.data('user-display-name'));
-					} else {
-						element.avatar(element.data('user'), 32);
-					}
-				});
-			});
-
-			$('#select-participants').on("select2-selecting", function(e) {
+			$('#select-participants').on('select2-selecting', function(e) {
 				switch (e.object.type) {
-					case "user":
+					case 'user':
 						this.connection.createOneToOneVideoCall(e.val);
 						break;
-					case "group":
-						this.connection.createGroupVideoCall(e.val, "");
+					case 'group':
+						this.connection.createGroupVideoCall(e.val, '');
 						break;
-					case "createPublicRoom":
+					case 'createPublicRoom':
 						this.connection.createPublicVideoCall(OCA.SpreedMe.app._searchTerm);
 						break;
-					case "createGroupRoom":
-						this.connection.createGroupVideoCall("", OCA.SpreedMe.app._searchTerm);
+					case 'createGroupRoom':
+						this.connection.createGroupVideoCall('', OCA.SpreedMe.app._searchTerm);
 						break;
 					default:
-						console.log("Unknown type", e.object.type);
+						console.log('Unknown type', e.object.type);
 						break;
 				}
 			}.bind(this));
 
-			$('#select-participants').on("select2-loaded", function() {
+			$('#select-participants').on('select2-loaded', function() {
 				$('.select2-drop').find('.avatar[data-user]').each(function () {
 					var element = $(this);
 					if (element.data('user-display-name')) {
@@ -212,35 +209,6 @@
 		},
 
 		registerLocalVideoButtonHandlers: function() {
-			$('#hideVideo').click(function() {
-				if(!OCA.SpreedMe.app.videoWasEnabledAtLeastOnce) {
-					// don't allow clicking the video toggle
-					// when no video ever was streamed (that
-					// means that permission wasn't granted
-					// yet or there is no video available at
-					// all)
-					console.log('video can not be enabled - there was no stream available before');
-					return;
-				}
-				if ($(this).hasClass('video-disabled')) {
-					OCA.SpreedMe.app.enableVideo();
-					localStorage.removeItem("videoDisabled");
-				} else {
-					OCA.SpreedMe.app.disableVideo();
-					localStorage.setItem("videoDisabled", true);
-				}
-			});
-
-			$('#mute').click(function() {
-				if (OCA.SpreedMe.webrtc.webrtc.isAudioEnabled()) {
-					OCA.SpreedMe.app.disableAudio();
-					localStorage.setItem("audioDisabled", true);
-				} else {
-					OCA.SpreedMe.app.enableAudio();
-					localStorage.removeItem("audioDisabled");
-				}
-			});
-
 			$('#video-fullscreen').click(function() {
 				if (this.fullscreenDisabled) {
 					this.enableFullscreen();
@@ -248,77 +216,6 @@
 					this.disableFullscreen();
 				}
 			}.bind(this));
-
-			$('#screensharing-button').click(function() {
-				var webrtc = OCA.SpreedMe.webrtc;
-				if (!webrtc.capabilities.supportScreenSharing) {
-					if (window.location.protocol === 'https:') {
-						OC.Notification.showTemporary(t('spreed', 'Screensharing is not supported by your browser.'));
-					} else {
-						OC.Notification.showTemporary(t('spreed', 'Screensharing requires the page to be loaded through HTTPS.'));
-					}
-					return;
-				}
-
-				if (webrtc.getLocalScreen()) {
-					$('#screensharing-menu').toggleClass('open');
-				} else {
-					var screensharingButton = $(this);
-					screensharingButton.prop('disabled', true);
-					webrtc.shareScreen(function(err) {
-						screensharingButton.prop('disabled', false);
-						if (!err) {
-							$('#screensharing-button').attr('data-original-title', t('spreed', 'Screensharing options'))
-								.removeClass('screensharing-disabled icon-screen-off')
-								.addClass('icon-screen');
-							return;
-						}
-
-						switch (err.name) {
-							case "HTTPS_REQUIRED":
-								OC.Notification.showTemporary(t('spreed', 'Screensharing requires the page to be loaded through HTTPS.'));
-								break;
-							case "PERMISSION_DENIED":
-							case "NotAllowedError":
-							case "CEF_GETSCREENMEDIA_CANCELED":  // Experimental, may go away in the future.
-								break;
-							case "FF52_REQUIRED":
-								OC.Notification.showTemporary(t('spreed', 'Sharing your screen only works with Firefox version 52 or newer.'));
-								break;
-							case "EXTENSION_UNAVAILABLE":
-								var  extensionURL = null;
-								if (!!window.chrome && !!window.chrome.webstore) {// Chrome
-									extensionURL = 'https://chrome.google.com/webstore/detail/screensharing-for-nextclo/kepnpjhambipllfmgmbapncekcmabkol';
-								}
-
-								if (extensionURL) {
-									var text = t('spreed', 'Screensharing extension is required to share your screen.');
-									var element = $('<a>').attr('href', extensionURL).attr('target','_blank').text(text);
-
-									OC.Notification.showTemporary(element, {isHTML: true});
-								} else {
-									OC.Notification.showTemporary(t('spreed', 'Please use a different browser like Firefox or Chrome to share your screen.'));
-								}
-								break;
-							default:
-								OC.Notification.showTemporary(t('spreed', 'An error occurred while starting screensharing.'));
-								console.log("Could not start screensharing", err);
-								break;
-						}
-					});
-				}
-			});
-
-			$("#show-screen-button").on('click', function() {
-				var currentUser = OCA.SpreedMe.webrtc.connection.getSessionid();
-				OCA.SpreedMe.sharedScreens.switchScreenToId(currentUser);
-
-				$('#screensharing-menu').toggleClass('open', false);
-			});
-
-			$("#stop-screen-button").on('click', function() {
-				OCA.SpreedMe.webrtc.stopScreenShare();
-			});
 		},
 
 		_onKeyUp: function(event) {
@@ -336,19 +233,11 @@
 				switch (key) {
 					case 86: // 'v'
 						event.preventDefault();
-						if (this.videoDisabled) {
-							this.enableVideo();
-						} else {
-							this.disableVideo();
-						}
+						this._mediaControlsView.toggleVideo();
 						break;
 					case 77: // 'm'
 						event.preventDefault();
-						if (this.audioDisabled) {
-							this.enableAudio();
-						} else {
-							this.disableAudio();
-						}
+						this._mediaControlsView.toggleAudio();
 						break;
 					case 70: // 'f'
 						event.preventDefault();
@@ -384,13 +273,15 @@
 				id: 'participantsTabView'
 			});
 
-			this.signaling.on('participantListChanged', function() {
+			this._participantsListChangedCallback = function() {
 				// The "participantListChanged" event can be triggered by the
 				// signaling before the room is set in the collection.
 				if (this._participants.url) {
 					this._participants.fetch();
 				}
-			}.bind(this));
+			}.bind(this);
+
+			this.signaling.on('participantListChanged', this._participantsListChangedCallback);
 
 			this._participantsView.listenTo(this._rooms, 'change:active', function(model, active) {
 				if (active) {
@@ -400,6 +291,15 @@
 
 			this._sidebarView.addTab('participants', { label: t('spreed', 'Participants'), icon: 'icon-contacts-dark' }, this._participantsView);
 		},
+		_hideParticipantList: function() {
+			this._sidebarView.removeTab('participants');
+
+			this.signaling.off('participantListChanged', this._participantsListChangedCallback);
+
+			delete this._participantsListChangedCallback;
+			delete this._participantsView;
+			delete this._participants;
+		},
 		/**
 		 * @param {string} token
 		 */
@@ -410,11 +310,12 @@
 				});
 			}
 		},
-		addParticipantToRoom: function(token, participant) {
+		addParticipantToRoom: function(token, participant, type) {
 			$.post(
 				OC.linkToOCS('apps/spreed/api/v1/room', 2) + token + '/participants',
 				{
-					newParticipant: participant
+					newParticipant: participant,
+					source: type
 				}
 			).done(function() {
 				this.signaling.syncRooms();
@@ -440,13 +341,14 @@
 						// The public page supports only a single room, so the
 						// active room is already the room for the given token.
 						participants = self.activeRoom.get('participants');
-						self.setRoomMessageForGuest(participants);
 					}
 					// Disable video when entering a room with more than 5 participants.
 					if (participants && Object.keys(participants).length > 5) {
 						self.disableVideo();
 					}
 
+					self._emptyContentView.setActiveRoom(self.activeRoom);
+
 					self.setPageTitle(self.activeRoom.get('displayName'));
 
 					self.updateContentsLayout();
@@ -464,18 +366,16 @@
 			var flags = this.activeRoom.get('participantFlags') || 0;
 			var inCall = flags & OCA.SpreedMe.app.FLAG_IN_CALL !== 0;
 			if (inCall && this._chatViewInMainView === true) {
-				this._chatView.saveScrollPosition();
 				this._chatView.$el.detach();
 				this._sidebarView.addTab('chat', { label: t('spreed', 'Chat'), icon: 'icon-comment', priority: 100 }, this._chatView);
 				this._sidebarView.selectTab('chat');
-				this._chatView.restoreScrollPosition();
+				this._chatView.reloadMessageList();
 				this._chatView.setTooltipContainer(this._chatView.$el);
 				this._chatViewInMainView = false;
 			} else if (!inCall && !this._chatViewInMainView) {
-				this._chatView.saveScrollPosition();
 				this._sidebarView.removeTab('chat');
 				this._chatView.$el.prependTo('#app-content-wrapper');
-				this._chatView.restoreScrollPosition();
+				this._chatView.reloadMessageList();
 				this._chatView.setTooltipContainer($('#app'));
 				this._chatView.focusChatInput();
 				this._chatViewInMainView = true;
@@ -525,74 +425,11 @@
 			title += ' - ' + oc_defaults.title;
 			window.document.title = title;
 		},
-		/**
-		 *
-		 * @param {string|Object} icon
-		 * @param {string} icon.userId
-		 * @param {string} icon.displayName
-		 * @param {string} message
-		 * @param {string} [messageAdditional]
-		 * @param {string} [url]
-		 */
-		setEmptyContentMessage: function(icon, message, messageAdditional, url) {
-			var $icon = $('#emptycontent-icon'),
-				$emptyContent = $('#emptycontent');
-
-			//Remove previous icon and avatar from emptycontent
-			$icon.removeAttr('class').attr('class', '');
-			$icon.html('');
-
-			if (url) {
-				$('#shareRoomInput').removeClass('hidden').val(url);
-				$('#shareRoomClipboardButton').removeClass('hidden');
-			} else {
-				$('#shareRoomInput').addClass('hidden');
-				$('#shareRoomClipboardButton').addClass('hidden');
-			}
-
-			if (typeof icon === 'string') {
-				$icon.addClass(icon);
-			} else {
-				var $avatar = $('<div>');
-				$avatar.addClass('avatar room-avatar');
-				if (icon.userId !== icon.displayName) {
-					$avatar.avatar(icon.userId, 128, undefined, false, undefined, icon.displayName);
-				} else {
-					$avatar.avatar(icon.userId, 128);
-				}
-				$icon.append($avatar);
-			}
-
-			$emptyContent.find('h2').html(message);
-			$emptyContent.find('p').text(messageAdditional ? messageAdditional : '');
-			this._lastEmptyContent = this._currentEmptyContent;
-			this._currentEmptyContent = arguments;
-		},
-		restoreEmptyContent: function() {
-			this.setEmptyContentMessage.apply(this, this._lastEmptyContent);
-		},
-		setRoomMessageForGuest: function(participants) {
-			if (Object.keys(participants).length === 1) {
-				var participantId = '',
-					participantName = '';
-
-				_.each(participants, function(data, userId) {
-					if (OC.getCurrentUser().uid !== userId) {
-						participantId = userId;
-						participantName = data.name;
-					}
-				});
-
-				OCA.SpreedMe.app.setEmptyContentMessage(
-					{ userId: participantId, displayName: participantName},
-					t('spreed', 'Waiting for {participantName} to join the call …', {participantName: participantName})
-				);
-
-			} else {
-				OCA.SpreedMe.app.setEmptyContentMessage('icon-contacts-dark', t('spreed', 'Waiting for others to join the call …'));
-			}
-		},
 		initialize: function() {
+			this._emptyContentView = new OCA.SpreedMe.Views.EmptyContentView({
+				el: '#app-content-wrapper > #emptycontent',
+			});
+
 			this._sidebarView = new OCA.SpreedMe.Views.SidebarView();
 			$('#content').append(this._sidebarView.$el);
 
@@ -610,10 +447,98 @@
 			this._messageCollection = new OCA.SpreedMe.Models.ChatMessageCollection(null, {token: null});
 			this._chatView = new OCA.SpreedMe.Views.ChatView({
 				collection: this._messageCollection,
-				id: 'commentsTabView',
+				id: 'chatView',
 				guestNameModel: this._localStorageModel
 			});
 
+			// Focus the chat input when the chat tab is selected.
+			this._chatView.listenTo(this._sidebarView, 'select:tab', function(tabId) {
+				if (tabId !== 'chat') {
+					return;
+				}
+
+				this._chatView.focusChatInput();
+			}.bind(this));
+
+			// Opening and closing the sidebar detachs its contents to perform
+			// the animation; detaching an element and attaching it again resets
+			// its scroll position, so the scroll position of the chat view
+			// needs to be saved before the sidebar is closed and restored again
+			// once the sidebar is opened.
+			this._chatView.listenTo(this._sidebarView, 'opened', function() {
+				if (this._sidebarView.getCurrentTabId() !== 'chat') {
+					return;
+				}
+
+				this._chatView.restoreScrollPosition();
+			}.bind(this));
+			this._chatView.listenTo(this._sidebarView, 'close', function() {
+				if (this._sidebarView.getCurrentTabId() !== 'chat') {
+					return;
+				}
+
+				this._chatView.saveScrollPosition();
+			}.bind(this));
+
+			// Selecting a different tab detachs the contents of the previous
+			// tab and attachs the contents of the new tab; detaching an element
+			// and attaching it again resets its scroll position, so the scroll
+			// position of the chat view needs to be saved when the chat tab is
+			// unselected and restored again when the chat tab is selected.
+			this._chatView.listenTo(this._sidebarView, 'unselect:tab', function(tabId) {
+				if (tabId !== 'chat') {
+					return;
+				}
+
+				this._chatView.saveScrollPosition();
+			}.bind(this));
+			this._chatView.listenTo(this._sidebarView, 'select:tab', function(tabId) {
+				if (tabId !== 'chat') {
+					return;
+				}
+
+				this._chatView.restoreScrollPosition();
+			}.bind(this));
+
+			// Opening or closing the sidebar changes the width of the main
+			// view, so if the chat view is in the main view it needs to be
+			// reloaded.
+			var reloadMessageListOnSidebarVisibilityChange = function() {
+				if (!this._chatViewInMainView) {
+					return;
+				}
+
+				this._chatView.reloadMessageList();
+			}.bind(this);
+			this._chatView.listenTo(this._sidebarView, 'opened', reloadMessageListOnSidebarVisibilityChange);
+			this._chatView.listenTo(this._sidebarView, 'closed', reloadMessageListOnSidebarVisibilityChange);
+
+			// Resizing the window can change the size of the chat view, both
+			// when it is in the main view and in the sidebar, so the chat view
+			// needs to be reloaded. The initial reload is not very heavy, so
+			// the handler is not debounced for a snappier feel and to reduce
+			// flickering.
+			// However, resizing the window below certain width causes the
+			// navigation bar to be hidden; an explicit handling is needed in
+			// this case because the app navigation (or, more specifically, its
+			// Snap object) adds a transition to the app content, so the reload
+			// needs to be delayed to give the transition time to end and thus
+			// give the app content time to get its final size.
+			var reloadMessageListOnWindowResize = function() {
+				var chatView = this._chatView;
+
+				if ($(window).width() >= 768 || !this._chatViewInMainView) {
+					chatView.reloadMessageList();
+
+					return;
+				}
+
+				setTimeout(function() {
+					chatView.reloadMessageList();
+				}, 300);
+			}.bind(this);
+			$(window).resize(reloadMessageListOnWindowResize);
+
 			this._messageCollection.listenTo(roomChannel, 'leaveCurrentRoom', function() {
 				this.stopReceivingMessages();
 			});
@@ -628,6 +553,14 @@
 				$('#emptycontent').show();
 			});
 
+			this._mediaControlsView = new OCA.SpreedMe.Views.MediaControlsView({
+				app: this,
+				webrtc: OCA.SpreedMe.webrtc,
+				sharedScreens: OCA.SpreedMe.sharedScreens,
+			});
+			this._mediaControlsView.render();
+			$('#localVideoContainer .nameIndicator').replaceWith(this._mediaControlsView.$el);
+
 			$(document).on('click', this.onDocumentClick);
 			OC.Util.History.addOnPopStateHandler(_.bind(this._onPopState, this));
 		},
@@ -645,7 +578,7 @@
 			}.bind(this));
 
 			$(window).unload(function () {
-				this.connection.leaveCurrentRoom(false);
+				this.connection.leaveCurrentRoom();
 				this.signaling.disconnect();
 			}.bind(this));
 
@@ -667,6 +600,18 @@
 				// in the public share auth page).
 				this.activeRoom = new OCA.SpreedMe.Models.Room({ token: this.token });
 				this.signaling.setRoom(this.activeRoom);
+
+				this.listenTo(this.activeRoom, 'change:participantType', function(model, participantType) {
+					if (participantType === OCA.SpreedMe.app.GUEST_MODERATOR) {
+						this._showParticipantList();
+						// The public page supports only a single room, so the
+						// active room has to be explicitly set as it will not
+						// be set in a 'change:active' event.
+						this._participantsView.setRoom(this.activeRoom);
+					} else {
+						this._hideParticipantList();
+					}
+				});
 			}
 
 			this._registerPageEvents();
@@ -679,7 +624,16 @@
 		setupWebRTC: function() {
 			if (!OCA.SpreedMe.webrtc) {
 				OCA.SpreedMe.initWebRTC(this);
+				this._mediaControlsView.setWebRtc(OCA.SpreedMe.webrtc);
+				this._mediaControlsView.setSharedScreens(OCA.SpreedMe.sharedScreens);
 			}
+
+			if (!OCA.SpreedMe.webrtc.capabilities.support) {
+				localMediaChannel.trigger('webRtcNotSupported');
+			} else {
+				localMediaChannel.trigger('waitingForPermissions');
+			}
+
 			OCA.SpreedMe.webrtc.startMedia(this.token);
 		},
 		startLocalMedia: function(configuration) {
@@ -690,24 +644,20 @@
 
 			$('.videoView').removeClass('hidden');
 			this.initAudioVideoSettings(configuration);
-			this.restoreEmptyContent();
+
+			localMediaChannel.trigger('startLocalMedia');
 		},
-		startWithoutLocalMedia: function(isAudioEnabled, isVideoEnabled) {
+		startWithoutLocalMedia: function(configuration) {
 			if (this.callbackAfterMedia) {
 				this.callbackAfterMedia(null);
 				this.callbackAfterMedia = null;
 			}
 
 			$('.videoView').removeClass('hidden');
+			this.initAudioVideoSettings(configuration);
 
-			this.disableAudio();
-			if (!isAudioEnabled) {
-				this.hasNoAudio();
-			}
-
-			this.disableVideo();
-			if (!isVideoEnabled) {
-				this.hasNoVideo();
+			if (OCA.SpreedMe.webrtc.capabilities.support) {
+				localMediaChannel.trigger('startWithoutLocalMedia');
 			}
 		},
 		_onPopState: function(params) {
@@ -721,17 +671,30 @@
 			uiChannel.trigger('document:click', event);
 		},
 		initAudioVideoSettings: function(configuration) {
-			if (this.audioDisabled) {
-				this.disableAudio();
+			if (configuration.audio !== false) {
+				this._mediaControlsView.hasAudio();
+
+				if (this._mediaControlsView.audioDisabled) {
+					this._mediaControlsView.disableAudio();
+				} else {
+					this._mediaControlsView.enableAudio();
+				}
+			} else {
+				this._mediaControlsView.disableAudio();
+				this._mediaControlsView.hasNoAudio();
 			}
 
 			if (configuration.video !== false) {
-				if (this.videoDisabled) {
+				this._mediaControlsView.hasVideo();
+
+				if (this._mediaControlsView.videoDisabled) {
 					this.disableVideo();
+				} else {
+					this.enableVideo();
 				}
 			} else {
-				this.videoWasEnabledAtLeastOnce = false;
 				this.disableVideo();
+				this._mediaControlsView.hasNoVideo();
 			}
 		},
 		enableFullscreen: function() {
@@ -765,83 +728,21 @@
 
 			this.fullscreenDisabled = true;
 		},
-		enableAudioButton: function() {
-			$('#mute').attr('data-original-title', t('spreed', 'Mute audio (m)'))
-				.removeClass('audio-disabled icon-audio-off')
-				.addClass('icon-audio');
-		},
-		enableAudio: function() {
-			if (this.audioNotFound || !OCA.SpreedMe.webrtc) {
-				return;
-			}
-			OCA.SpreedMe.webrtc.unmute();
-			this.enableAudioButton();
-			this.audioDisabled = false;
-		},
-		disableAudioButton: function() {
-			$('#mute').attr('data-original-title', t('spreed', 'Unmute audio (m)'))
-				.addClass('audio-disabled icon-audio-off')
-				.removeClass('icon-audio');
-		},
-		disableAudio: function() {
-			if (this.audioNotFound || !OCA.SpreedMe.webrtc) {
-				return;
-			}
-			OCA.SpreedMe.webrtc.mute();
-			this.disableAudioButton();
-			this.audioDisabled = true;
-		},
-		hasAudio: function() {
-			$('#mute').removeClass('no-audio-available');
-			this.enableAudioButton();
-			this.audioNotFound = false;
-		},
-		hasNoAudio: function() {
-			$('#mute').removeClass('audio-disabled icon-audio')
-				.addClass('no-audio-available icon-audio-off')
-				.attr('data-original-title', t('spreed', 'No audio'));
-			this.audioDisabled = true;
-			this.audioNotFound = true;
-		},
 		enableVideoUI: function() {
-			var $hideVideoButton = $('#hideVideo');
-			var $audioMuteButton = $('#mute');
-			var $screensharingButton = $('#screensharing-button');
-			var avatarContainer = $hideVideoButton.closest('.videoView').find('.avatar-container');
-			var localVideo = $hideVideoButton.closest('.videoView').find('#localVideo');
-
-			$hideVideoButton.attr('data-original-title', t('spreed', 'Disable video (v)'))
-				.removeClass('local-video-disabled video-disabled icon-video-off')
-				.addClass('icon-video');
-			$audioMuteButton.removeClass('local-video-disabled');
-			$screensharingButton.removeClass('local-video-disabled');
+			var avatarContainer = this._mediaControlsView.$el.closest('.videoView').find('.avatar-container');
+			var localVideo = this._mediaControlsView.$el.closest('.videoView').find('#localVideo');
 
 			avatarContainer.hide();
 			localVideo.show();
 		},
 		enableVideo: function() {
-			if (this.videoNotFound || !OCA.SpreedMe.webrtc) {
-				return;
+			if (this._mediaControlsView.enableVideo()) {
+				this.enableVideoUI();
 			}
-
-			OCA.SpreedMe.webrtc.resumeVideo();
-			this.enableVideoUI();
-			this.videoDisabled = false;
 		},
 		hideVideo: function() {
-			var $hideVideoButton = $('#hideVideo');
-			var $audioMuteButton = $('#mute');
-			var $screensharingButton = $('#screensharing-button');
-			var avatarContainer = $hideVideoButton.closest('.videoView').find('.avatar-container');
-			var localVideo = $hideVideoButton.closest('.videoView').find('#localVideo');
-
-			if (!$hideVideoButton.hasClass('no-video-available')) {
-				$hideVideoButton.attr('data-original-title', t('spreed', 'Enable video (v)'))
-					.addClass('local-video-disabled video-disabled icon-video-off')
-					.removeClass('icon-video');
-				$audioMuteButton.addClass('local-video-disabled');
-				$screensharingButton.addClass('local-video-disabled');
-			}
+			var avatarContainer = this._mediaControlsView.$el.closest('.videoView').find('.avatar-container');
+			var localVideo = this._mediaControlsView.$el.closest('.videoView').find('#localVideo');
 
 			var avatar = avatarContainer.find('.avatar');
 			var guestName = localStorage.getItem("nick");
@@ -861,31 +762,13 @@
 			localVideo.hide();
 		},
 		disableVideo: function() {
-			if (this.videoNotFound || !OCA.SpreedMe.webrtc) {
-				return;
-			}
-
-			OCA.SpreedMe.webrtc.pauseVideo();
+			this._mediaControlsView.disableVideo();
+			// Always hide the video, even if "disableVideo" returned "false".
 			this.hideVideo();
-			this.videoDisabled = true;
-		},
-		hasVideo: function() {
-			$('#hideVideo').removeClass('no-video-available');
-			this.enableVideoUI();
-			this.videoNotFound = false;
-		},
-		hasNoVideo: function() {
-			$('#hideVideo').removeClass('icon-video')
-				.addClass('no-video-available icon-video-off')
-				.attr('data-original-title', t('spreed', 'No Camera'));
-			this.videoDisabled = true;
-			this.videoNotFound = true;
 		},
+		// Called from webrtc.js
 		disableScreensharingButton: function() {
-			$('#screensharing-button').attr('data-original-title', t('spreed', 'Enable screensharing'))
-					.addClass('screensharing-disabled icon-screen-off')
-					.removeClass('icon-screen');
-			$('#screensharing-menu').toggleClass('open', false);
+			this._mediaControlsView.disableScreensharingButton();
 		},
 		setGuestName: function(name) {
 			$.ajax({
