@@ -29,23 +29,22 @@
 	OCA.SpreedMe.Views = OCA.SpreedMe.Views || {};
 
 	var TEMPLATE =
-		'<div class="room-name"></div>' +
-		'<div class="call-controls-container">' +
-		'	<div class="call-button">' +
-		'	{{#if isInCall}}' +
-		'		<button class="leave-call primary">' + t('spreed', 'Leave call') + '</button>' +
-		'	{{else}}' +
-		'		{{#if hasCall}}' +
-		'		<button class="join-call call-ongoing primary">' + t('spreed', 'Join call') + '</button>' +
-		'		{{else}}' +
-		'		<button class="join-call primary">' + t('spreed', 'Start call') + '</button>' +
-		'		{{/if}}' +
+		'<div class="room-name-container">' +
+		'	<div class="room-name"></div>' +
+		'	{{#if isRoomForFile}}' +
+		'	<a class="file-link" href="{{fileLink}}" target="_blank" rel="noopener noreferrer" data-original-title="{{fileLinkTitle}}">' +
+		'		<span class="icon icon-file"></span>' +
+		'	</a>' +
 		'	{{/if}}' +
-		'	</div>' +
+		'</div>' +
+		'<div class="call-controls-container">' +
+		'	<div class="call-button"></div>' +
 		'{{#if canModerate}}' +
 		'	<div class="share-link-options">' +
+		'		{{#if canFullModerate}}' +
 		'		<input name="link-checkbox" id="link-checkbox" class="checkbox link-checkbox" value="1" {{#if isPublic}} checked="checked"{{/if}} type="checkbox">' +
 		'		<label for="link-checkbox" class="link-checkbox-label">' + t('spreed', 'Share link') + '</label>' +
+		'		{{/if}}' +
 		'		{{#if isPublic}}' +
 		'			<div class="clipboard-button"><span class="button icon-clippy"></span></div>' +
 		'			<div class="password-button">' +
@@ -85,9 +84,11 @@
 		templateContext: function() {
 			var canModerate = this._canModerate();
 			return $.extend(this.model.toJSON(), {
-				isGuest: this.model.get('participantType') === 4,
-				isInCall: (this.model.get('participantFlags') & OCA.SpreedMe.app.FLAG_IN_CALL) !== 0,
+				isRoomForFile: this.model.get('objectType') === 'file',
+				fileLink: OC.generateUrl('/f/{fileId}', { fileId: this.model.get('objectId') }),
+				fileLinkTitle: t('spreed', 'Go to file'),
 				canModerate: canModerate,
+				canFullModerate: this._canFullModerate(),
 				isPublic: this.model.get('type') === 3,
 				showShareLink: !canModerate && this.model.get('type') === 3,
 				isDeletable: canModerate && (Object.keys(this.model.get('participants')).length > 2 || this.model.get('numGuests') > 0)
@@ -96,12 +97,12 @@
 
 		ui: {
 			'roomName': 'div.room-name',
+			'fileLink': '.file-link',
 			'shareLinkOptions': '.share-link-options',
 			'clipboardButton': '.clipboard-button',
 			'linkCheckbox': '.link-checkbox',
 
-			'joinCallButton': 'button.join-call',
-			'leaveCallButton': 'button.leave-call',
+			'callButton': 'div.call-button',
 
 			'passwordButton': '.password-button .button',
 			'passwordForm': '.password-form',
@@ -115,6 +116,7 @@
 
 		regions: {
 			'roomName': '@ui.roomName',
+			'callButton': '@ui.callButton',
 		},
 
 		events: {
@@ -124,20 +126,12 @@
 			'click @ui.passwordButton': 'showPasswordInput',
 			'click @ui.passwordConfirm': 'confirmPassword',
 			'submit @ui.passwordForm': 'confirmPassword',
-			'click @ui.joinCallButton': 'joinCall',
-			'click @ui.leaveCallButton': 'leaveCall',
 		},
 
 		modelEvents: {
 			'change:hasPassword': function() {
 				this.renderWhenInactive();
 			},
-			'change:hasCall': function() {
-				this.renderWhenInactive();
-			},
-			'change:participantFlags': function() {
-				this.renderWhenInactive();
-			},
 			'change:participantType': function() {
 				this._updateNameEditability();
 
@@ -179,6 +173,11 @@
 				buttonTitle: t('spreed', 'Rename')
 			});
 
+			this._callButton = new OCA.SpreedMe.Views.CallButton({
+				model: this.model,
+				connection: OCA.SpreedMe.app.connection,
+			});
+
 			this._updateNameEditability();
 		},
 
@@ -202,6 +201,7 @@
 			// rendered, as the element of the region does not exist yet at that
 			// time and without that option the call would fail otherwise.
 			this.getRegion('roomName').reset({ preventDestroy: true, allowMissingEl: true });
+			this.getRegion('callButton').reset({ preventDestroy: true, allowMissingEl: true });
 		},
 
 		onRender: function() {
@@ -210,9 +210,10 @@
 				this.renderTimeout = undefined;
 			}
 
-			// Attach the child view again (or for the first time) after the
+			// Attach the child views again (or for the first time) after the
 			// template has been rendered.
 			this.showChildView('roomName', this._nameEditableTextLabel, { replaceElement: true } );
+			this.showChildView('callButton', this._callButton, { replaceElement: true } );
 
 			var roomURL = OC.generateUrl('/call/' + this.model.get('token')),
 				completeURL = window.location.protocol + '//' + window.location.host + roomURL;
@@ -232,6 +233,10 @@
 				title: (this.model.get('hasPassword')) ? t('spreed', 'Change password') : t('spreed', 'Set password')
 			});
 
+			// Set the body as the container to show the tooltip in front of the
+			// header.
+			this.ui.fileLink.tooltip({container: $('body')});
+
 			var self = this;
 			OC.registerMenu($(this.ui.passwordButton), $(this.ui.passwordMenu), function() {
 				$(self.ui.passwordInput).focus();
@@ -240,6 +245,10 @@
 		},
 
 		_canModerate: function() {
+			return this._canFullModerate() || this.model.get('participantType') === 6;
+		},
+
+		_canFullModerate: function() {
 			return this.model.get('participantType') === 1 || this.model.get('participantType') === 2;
 		},
 
@@ -286,14 +295,6 @@
 			});
 		},
 
-		joinCall: function() {
-			OCA.SpreedMe.app.connection.joinCall(this.model.get('token'));
-		},
-
-		leaveCall: function() {
-			OCA.SpreedMe.app.connection.leaveCurrentCall();
-		},
-
 		/**
 		 * Password
 		 */
