@@ -1,4 +1,4 @@
-/* global autosize, Handlebars, Marionette, moment, OC, OCA, OCP */
+/* global autosize, Marionette, moment, OC, OCA, OCP */
 
 /**
  *
@@ -21,51 +21,13 @@
  *
  */
 
-(function(OCA, OC, OCP, Marionette, Handlebars, autosize, moment) {
+(function(OCA, OC, OCP, Marionette, autosize, moment) {
 	'use strict';
 
 	OCA.SpreedMe = OCA.SpreedMe || {};
+	OCA.Talk = OCA.Talk || {};
 	OCA.SpreedMe.Views = OCA.SpreedMe.Views || {};
-
-	var TEMPLATE =
-		'<ul class="comments">' +
-		'</ul>' +
-		'<div class="emptycontent"><div class="icon-comment"></div>' +
-		'<p>{{emptyResultLabel}}</p></div>' +
-		'<div class="loading hidden" style="height: 50px"></div>';
-
-	var ADD_COMMENT_TEMPLATE =
-		'<div class="newCommentRow comment">' +
-		'    <div class="authorRow currentUser">' +
-		'        <div class="avatar" data-user-id="{{actorId}}"></div>' +
-		'        {{#if actorId}}' +
-		'            <div class="author">{{actorDisplayName}}</div>' +
-		'        {{else}}' +
-		'            <div class="guest-name"></div>' +
-		'        {{/if}}' +
-		'    </div>' +
-		'    <form class="newCommentForm">' +
-		'        <div contentEditable="true" class="message" data-placeholder="{{newMessagePlaceholder}}">{{message}}</div>' +
-		'        <input class="submit icon-confirm has-tooltip" type="submit" value="" title="{{submitText}}"/>' +
-		'        <div class="submitLoading icon-loading-small hidden"></div>'+
-		'        {{#if actorId}}' +
-		'        <button class="share icon-add has-tooltip" title="{{shareText}}"></button>' +
-		'        <div class="shareLoading icon-loading-small hidden"></div>'+
-		'        {{/if}}' +
-		'    </form>' +
-		'</div>';
-
-	var COMMENT_TEMPLATE =
-		'<li class="comment{{#if isNotSystemMessage}}{{else}} systemMessage{{/if}}" data-id="{{id}}">' +
-		'    <div class="authorRow{{#if isUserAuthor}} currentUser{{/if}}{{#if isGuest}} guestUser{{/if}}">' +
-		'        {{#if isNotSystemMessage}}' +
-		'        <div class="avatar" data-user-id="{{#if isGuest}}{{else}}{{actorId}}{{/if}}" data-user-display-name="{{actorDisplayName}}"> </div>' +
-		'        <div class="author">{{actorDisplayName}}</div>' +
-		'        {{/if}}' +
-		'        <div class="date has-tooltip{{#if relativeDate}} live-relative-timestamp{{/if}}" data-timestamp="{{timestamp}}" title="{{altDate}}">{{date}}</div>' +
-		'    </div>' +
-		'    <div class="message">{{{formattedMessage}}}</div>' +
-		'</li>';
+	OCA.Talk.Views = OCA.Talk.Views || {};
 
 	var ChatView = Marionette.View.extend({
 
@@ -89,7 +51,9 @@
 
 		initialize: function() {
 			this.listenTo(this.collection, 'reset', this.render);
+			this.listenTo(this.collection, 'add:start', this._onAddModelStart);
 			this.listenTo(this.collection, 'add', this._onAddModel);
+			this.listenTo(this.collection, 'add:end', this._onAddModelEnd);
 
 			this._guestNameEditableTextLabel = new OCA.SpreedMe.Views.EditableTextLabel({
 				model: this.getOption('guestNameModel'),
@@ -125,7 +89,7 @@
 					sorter: function (q, items) { return items; }
 				},
 				displayTpl: function (item) {
-					return '<li>' +
+					return '<li class="chat-view-mention-autocomplete">' +
 						'<span class="avatar-name-wrapper">' +
 							'<span class="avatar" ' +
 									'data-user-id="' + escapeHTML(item.id) + '" ' +
@@ -199,14 +163,19 @@
 			document.execCommand('insertText', false, text);
 		},
 
-		template: Handlebars.compile(TEMPLATE),
+		template: function(context) {
+			// OCA.Talk.Views.Templates may not have been initialized when
+			// this view is initialized, so the template can not be directly
+			// assigned.
+			return OCA.Talk.Views.Templates['chatview'](context);
+		},
 		templateContext: {
 			emptyResultLabel: t('spreed', 'No messages yet, start the conversation!')
 		},
 
 		addCommentTemplate: function(params) {
 			if (!this._addCommentTemplate) {
-				this._addCommentTemplate = Handlebars.compile(ADD_COMMENT_TEMPLATE);
+				this._addCommentTemplate = OCA.Talk.Views.Templates['chatview_add_comment'];
 			}
 
 			return this._addCommentTemplate(_.extend({
@@ -220,7 +189,7 @@
 
 		commentTemplate: function(params) {
 			if (!this._commentTemplate) {
-				this._commentTemplate = Handlebars.compile(COMMENT_TEMPLATE);
+				this._commentTemplate = OCA.Talk.Views.Templates['chatview_comment'];
 			}
 
 			params = _.extend({
@@ -244,6 +213,8 @@
 			this.$el.find('.has-tooltip').tooltip({container: this._tooltipContainer});
 			this.$container = this.$el.find('ul.comments');
 
+			this._virtualList = new OCA.SpreedMe.Views.VirtualList(this.$container);
+
 			if (OC.getCurrentUser().uid) {
 				this.$el.find('.avatar').avatar(OC.getCurrentUser().uid, 32, undefined, false, undefined, OC.getCurrentUser().displayName);
 			} else {
@@ -304,56 +275,86 @@
 		 * be able to restore the scroll position when attached again.
 		 */
 		saveScrollPosition: function() {
-			var self = this;
-
 			if (_.isUndefined(this.$container)) {
 				return;
 			}
 
-			var containerHeight = this.$container.outerHeight();
-
-			this._$lastVisibleComment = this.$container.children('.comment').filter(function() {
-					return self._getCommentTopPosition($(this)) < containerHeight;
-			}).last();
+			this._savedScrollPosition = this.$container.scrollTop();
 		},
 
 		/**
-		 * Restores the scroll position of the message list to the last saved
-		 * position.
+		 * Restores the scroll position of the message list.
 		 *
-		 * When the scroll position is restored the size of the message list may
-		 * have changed (for example, if the chat view was detached from the
-		 * main view and attached to the sidebar); it is not possible to
-		 * guarantee that exactly the same messages that were visible when the
-		 * scroll position was saved will be visible when the scroll position is
-		 * restored. Due to this, restoring the scroll position just ensures
-		 * that the last message that was partially visible when it was saved
-		 * will be fully visible when it is restored.
+		 * The scroll position is restored to the given position or, if none is
+		 * given, to the last saved position. If neither a scroll position is
+		 * given nor a scroll position was saved the current scroll position is
+		 * not modified.
+		 *
+		 * Note that the saved scroll position is valid only if the chat view
+		 * was not resized since it was saved; restoring the scroll position
+		 * after the chat view was resized may or may not work as expected.
+		 *
+		 * @param {number} scrollPosition the scroll position to restore to, or
+		 *                 undefined to restore to the last saved position.
 		 */
-		restoreScrollPosition: function() {
-			if (_.isUndefined(this.$container) || _.isUndefined(this._$lastVisibleComment)) {
+		restoreScrollPosition: function(scrollPosition) {
+			if (_.isUndefined(this.$container) ||
+					(_.isUndefined(this._savedScrollPosition) && _.isUndefined(scrollPosition))) {
 				return;
 			}
 
-			var scrollBottom = 0;
+			if (_.isUndefined(scrollPosition)) {
+				this.$container.scrollTop(this._savedScrollPosition);
 
-			// When the last visible comment has a next sibling the scroll
-			// position is based on the top position of that next sibling.
-			// Basing it on the last visible comment top position and its height
-			// could cause the next sibling to be shown due to a negative margin
-			// "pulling it up" over the last visible comment bottom margin.
-			var $nextSibling = this._$lastVisibleComment.next();
-			if ($nextSibling.length > 0) {
-				// Substract 1px to ensure that it does not scroll into the next
-				// element (which would cause the next element to be fully shown
-				// if saving and restoring the scroll position again) due to
-				// rounding.
-				scrollBottom = this._getCommentTopPosition($nextSibling) - 1;
-			} else if (this._$lastVisibleComment.length > 0) {
-				scrollBottom = this._getCommentTopPosition(this._$lastVisibleComment) + this._getCommentOuterHeight(this._$lastVisibleComment);
+				return;
 			}
 
-			this.$container.scrollTop(scrollBottom - this.$container.outerHeight());
+			this.$container.scrollTop(scrollPosition);
+		},
+
+		/**
+		 * Returns the last known scroll position of the message list.
+		 *
+		 * Note that this value is updated asynchronously, so in some cases it
+		 * will not match the current scroll position of the message list.
+		 * Moreover, it could also be influenced in surprising ways, for
+		 * example, by animations that change the width of the message list.
+		 *
+		 * If possible, save the scroll position explicitly at a known safe
+		 * point to be able to restore to it instead of restoring to the value
+		 * returned by this method.
+		 *
+		 * @return {number} the last known scroll position of the message list.
+		 */
+		getLastKnownScrollPosition: function() {
+			if (_.isUndefined(this._virtualList)) {
+				return;
+			}
+
+			return this._virtualList.getLastKnownScrollPosition();
+		},
+
+		/**
+		 * Reloads the message list.
+		 *
+		 * This needs to be called whenever the size of the chat view has
+		 * changed.
+		 *
+		 * When the message list is reloaded its size may have changed (for
+		 * example, if the chat view was detached from the main view and
+		 * attached to the sidebar); it is not possible to guarantee that
+		 * exactly the same messages that were visible before will be visible
+		 * after the message list is reloaded. Due to this, in those cases
+		 * reloading the message list just ensures that the last message that
+		 * was partially visible before will be fully visible after the message
+		 * list is reloaded.
+		 */
+		reloadMessageList: function() {
+			if (!this._virtualList) {
+				return;
+			}
+
+			this._virtualList.reload();
 		},
 
 		_formatItem: function(commentModel) {
@@ -373,7 +374,7 @@
 
 			var formattedMessage = escapeHTML(commentModel.get('message')).replace(/\n/g, '<br/>');
 			formattedMessage = OCP.Comments.plainToRich(formattedMessage);
-			formattedMessage = OCA.SpreedMe.RichObjectStringParser.parseMessage(
+			formattedMessage = OCA.SpreedMe.Views.RichObjectStringParser.parseMessage(
 				formattedMessage, commentModel.get('messageParameters'));
 
 			var data = _.extend({}, commentModel.attributes, {
@@ -388,18 +389,15 @@
 			return data;
 		},
 
-		_onAddModel: function(model, collection, options) {
-			this.$el.find('.emptycontent').toggleClass('hidden', true);
+		_onAddModelStart: function() {
+			this._virtualList.appendElementStart();
 
-			var $newestComment = this.$container.children('.comment').last();
-			var scrollToNew = $newestComment.length > 0 && this._getCommentTopPosition($newestComment) < this.$container.outerHeight();
+			this._scrollToNew = this._virtualList.getLastElement() === this._virtualList.getLastVisibleElement();
+		},
 
+		_onAddModel: function(model) {
 			var $el = $(this.commentTemplate(this._formatItem(model)));
-			if (!_.isUndefined(options.at) && collection.length > 1) {
-				this.$container.find('li').eq(options.at).before($el);
-			} else {
-				this.$container.append($el);
-			}
+			this._virtualList.appendElement($el);
 
 			if (this._modelsHaveSameActor(this._lastAddedMessageModel, model) &&
 					this._modelsAreTemporaryNear(this._lastAddedMessageModel, model) &&
@@ -427,42 +425,16 @@
 			this._lastAddedMessageModel = model;
 
 			this._postRenderItem(model, $el);
-
-			if (scrollToNew) {
-				var newestCommentHiddenHeight = (this._getCommentTopPosition($newestComment) + this._getCommentOuterHeight($newestComment)) - this.$container.outerHeight();
-				this.$container.scrollTop(this.$container.scrollTop() + newestCommentHiddenHeight + $el.outerHeight(true));
-			}
 		},
 
-		_getCommentTopPosition: function($element) {
-			// When the margin is positive, jQuery returns the proper top
-			// position of the element (that is, including the top margin).
-			// However, when it is negative, jQuery returns where the top
-			// position of the element would be if there was no margin. Grouped
-			// messages use a negative top margin to "pull them up" closer to
-			// the previous message, so in those cases the top position returned
-			// by jQuery is below the actual top position of the element.
-			var marginTop = parseInt($element.css('margin-top'));
-			if (marginTop >= 0) {
-				return $element.position().top;
+		_onAddModelEnd: function() {
+			this.$el.find('.emptycontent').toggleClass('hidden', true);
+
+			this._virtualList.appendElementEnd();
+
+			if (this._scrollToNew) {
+				this._virtualList.scrollTo(this._virtualList.getLastElement());
 			}
-
-			return $element.position().top + marginTop;
-		},
-
-		_getCommentOuterHeight: function($element) {
-			// When the margin is positive, jQuery returns the proper outer
-			// height of the element. However, when it is negative, it
-			// substracts the negative margin from the overall height of the
-			// element. Grouped messages use a negative top margin to "pull them
-			// up" closer to the previous message, so in those cases the outer
-			// height returned by jQuery is smaller than the actual height.
-			var marginTop = parseInt($element.css('margin-top'));
-			if (marginTop >= 0) {
-				return $element.outerHeight(true);
-			}
-
-			return $element.outerHeight(true) - marginTop;
 		},
 
 		_getDateSeparator: function(timestamp) {
@@ -655,21 +627,21 @@
 			var $comment = $el.clone();
 
 			$comment.find('.mention-user').each(function () {
-				var $this = $(this);
-				var $inserted = $this.parent();
-				$inserted.html('@' + $this.find('.avatar').data('user-id'));
+				var $this = $(this),
+					$inserted = $this.parent(),
+					userId = $this.find('.avatar').data('user-id');
+				if (userId.indexOf(' ') !== -1) {
+					$inserted.html('@"' + userId + '"');
+				} else {
+					$inserted.html('@' + userId);
+				}
 			});
 
-			var oldHtml;
-			var html = $comment.html();
-			do {
-				// replace works one by one
-				oldHtml = html;
-				html = oldHtml.replace("<br>", "\n");	// preserve line breaks
-			} while(oldHtml !== html);
-			$comment.html(html);
+			$comment.html($comment.html().replace(/<br>/g, "\n"));
+			var message = $comment.text();
 
-			return $comment.text();
+			// Little hack to replace the non-breaking space resulting from the editable div content with normal spaces
+			return decodeURI(encodeURI(message).replace(/%C2%A0/g, '%20'));
 		},
 
 		_onSubmitComment: function(e) {
@@ -706,8 +678,12 @@
 				success: function(model) {
 					self._onSubmitSuccess(model, $form);
 				},
-				error: function() {
-					self._onSubmitError($form);
+				error: function(model, response) {
+					if (response.status === 413) {
+						self._onSubmitError($form, t('spreed', 'The message you are trying to send is too long'));
+					} else {
+						self._onSubmitError($form, t('spreed', 'Error occurred while sending message'));
+					}
 				}
 			});
 
@@ -726,14 +702,14 @@
 			// thanks to the auto-refresh of the list.
 		},
 
-		_onSubmitError: function($form) {
+		_onSubmitError: function($form, errorMsg) {
 			$form.find('.submit').removeClass('hidden');
 			$form.find('.submitLoading').addClass('hidden');
 			$form.find('.message').prop('contenteditable', true);
 
 			$form.find('.message').focus();
 
-			OC.Notification.show(t('spreed', 'Error occurred while sending message'), {type: 'error'});
+			OC.Notification.show(errorMsg, {type: 'error'});
 		},
 
 		_onAddShare: function() {
@@ -778,4 +754,4 @@
 
 	OCA.SpreedMe.Views.ChatView = ChatView;
 
-})(OCA, OC, OCP, Marionette, Handlebars, autosize, moment);
+})(OCA, OC, OCP, Marionette, autosize, moment);
