@@ -35,6 +35,7 @@
 			' {{name}}' +
 			'{{#if participantIsOwner}}<span class="participant-moderator-indicator">(' + t('spreed', 'moderator') + ')</span>{{/if}}' +
 			'{{#if participantIsModerator}}<span class="participant-moderator-indicator">(' + t('spreed', 'moderator') + ')</span>{{/if}}' +
+			'{{#if participantIsGuestModerator}}<span class="participant-moderator-indicator">(' + t('spreed', 'moderator') + ')</span>{{/if}}' +
 			'{{#if inCall}}<span class="icon icon-video"></span>{{/if}}' +
 		'</a>'+
 		'{{#if canModerate}}' +
@@ -48,7 +49,7 @@
 			'</div>'+
 			'<div class="popovermenu bubble menu">'+
 				'<ul class="popovermenu-list">'+
-					'{{#if participantIsModerator}}' +
+					'{{#if canBeDemoted}}' +
 					'<li>' +
 						'<button class="demote-moderator">' +
 							'<span class="icon icon-star"></span>' +
@@ -56,7 +57,7 @@
 						'</button>' +
 					'</li>' +
 					'{{else}}' +
-						'{{#if participantIsUser}}' +
+						'{{#if canBePromoted}}' +
 						'<li>' +
 							'<button class="promote-moderator">' +
 								'<span class="icon icon-rename"></span>' +
@@ -108,10 +109,19 @@
 				});
 			},
 			templateContext: function() {
+				var isSelf = false,
+					isModerator = false;
+				if (OC.getCurrentUser().uid) {
+					isSelf = this.model.get('userId') === OC.getCurrentUser().uid;
+					isModerator = OCA.SpreedMe.app.activeRoom.get('participantType') === OCA.SpreedMe.app.OWNER ||
+						OCA.SpreedMe.app.activeRoom.get('participantType') === OCA.SpreedMe.app.MODERATOR;
+				} else {
+					isSelf = this.model.get('sessionId') === OCA.SpreedMe.app.activeRoom.get('sessionId');
+					isModerator = OCA.SpreedMe.app.activeRoom.get('participantType') === OCA.SpreedMe.app.GUEST_MODERATOR;
+				}
+
 				var canModerate = this.model.get('participantType') !== OCA.SpreedMe.app.OWNER &&       // can not moderate owners
-					this.model.get('userId') !== OC.getCurrentUser().uid &&                // can not moderate yourself
-					(OCA.SpreedMe.app.activeRoom.get('participantType') === OCA.SpreedMe.app.OWNER ||   // current user must be owner
-						OCA.SpreedMe.app.activeRoom.get('participantType') === OCA.SpreedMe.app.MODERATOR), // or moderator.
+					!isSelf && isModerator,
 					name = '';
 
 
@@ -123,8 +133,11 @@
 
 				return {
 					canModerate: canModerate,
+					canBePromoted: this.model.get('participantType') === OCA.SpreedMe.app.USER || this.model.get('participantType') === OCA.SpreedMe.app.GUEST,
+					canBeDemoted: this.model.get('participantType') === OCA.SpreedMe.app.MODERATOR || this.model.get('participantType') === OCA.SpreedMe.app.GUEST_MODERATOR,
 					name: name,
 					participantIsUser: this.model.get('participantType') === OCA.SpreedMe.app.USER,
+					participantIsGuestModerator: this.model.get('participantType') === OCA.SpreedMe.app.GUEST_MODERATOR,
 					participantIsModerator: this.model.get('participantType') === OCA.SpreedMe.app.MODERATOR,
 					participantIsOwner: this.model.get('participantType') === OCA.SpreedMe.app.OWNER
 				};
@@ -134,11 +147,14 @@
 				this.$el.find('.avatar').each(function() {
 					var $element = $(this);
 
-					if (model.get('participantType') !== OCA.SpreedMe.app.GUEST) {
-						$element.avatar(model.get('userId'), 32, undefined, false, undefined, model.get('displayName'));
-					} else {
+					if (model.get('participantType') === OCA.SpreedMe.app.GUEST_MODERATOR) {
+						$element.imageplaceholder('M', model.get('displayName'), 32);
+						$element.css('background-color', '#b9b9b9');
+					} else if (model.get('participantType') === OCA.SpreedMe.app.GUEST) {
 						$element.imageplaceholder('?', model.get('displayName'), 32);
 						$element.css('background-color', '#b9b9b9');
+					} else {
+						$element.avatar(model.get('userId'), 32, undefined, false, undefined, model.get('displayName'));
 					}
 				});
 
@@ -181,7 +197,8 @@
 				this.toggleMenuClass();
 			},
 			promoteToModerator: function() {
-				if (this.model.get('participantType') !== OCA.SpreedMe.app.USER) {
+				if (this.model.get('participantType') !== OCA.SpreedMe.app.USER &&
+					this.model.get('participantType') !== OCA.SpreedMe.app.GUEST) {
 					return;
 				}
 
@@ -189,17 +206,29 @@
 				this.ui.menuButton.addClass('hidden');
 				this.ui.menuButtonIconLoading.removeClass('hidden');
 
-				var participantId = this.model.get('userId'),
+				var data = {},
 					self = this;
 
+				if (this.model.get('userId')) {
+					data = {
+						participant: this.model.get('userId')
+					};
+				} else {
+					data = {
+						sessionId: this.model.get('sessionId')
+					};
+				}
+
 				$.ajax({
 					type: 'POST',
 					url: OC.linkToOCS('apps/spreed/api/v1/room', 2) + OCA.SpreedMe.app.activeRoom.get('token') + '/moderators',
-					data: {
-						participant: participantId
-					},
+					data: data,
 					success: function() {
-						self.model.set('participantType', OCA.SpreedMe.app.MODERATOR);
+						if (self.model.get('userId')) {
+							self.model.set('participantType', OCA.SpreedMe.app.MODERATOR);
+						} else {
+							self.model.set('participantType', OCA.SpreedMe.app.GUEST_MODERATOR);
+						}
 						// When an attribute that affects the order of a
 						// collection is set the collection has to be explicitly
 						// sorted again.
@@ -214,7 +243,8 @@
 				});
 			},
 			demoteFromModerator: function() {
-				if (this.model.get('participantType') !== OCA.SpreedMe.app.MODERATOR) {
+				if (this.model.get('participantType') !== OCA.SpreedMe.app.MODERATOR &&
+					this.model.get('participantType') !== OCA.SpreedMe.app.GUEST_MODERATOR) {
 					return;
 				}
 
@@ -222,17 +252,29 @@
 				this.ui.menuButton.addClass('hidden');
 				this.ui.menuButtonIconLoading.removeClass('hidden');
 
-				var participantId = this.model.get('userId'),
+				var data = {},
 					self = this;
 
+				if (this.model.get('userId')) {
+					data = {
+						participant: this.model.get('userId')
+					};
+				} else {
+					data = {
+						sessionId: this.model.get('sessionId')
+					};
+				}
+
 				$.ajax({
 					type: 'DELETE',
 					url: OC.linkToOCS('apps/spreed/api/v1/room', 2) + OCA.SpreedMe.app.activeRoom.get('token') + '/moderators',
-					data: {
-						participant: participantId
-					},
+					data:data,
 					success: function() {
-						self.model.set('participantType', OCA.SpreedMe.app.USER);
+						if (self.model.get('userId')) {
+							self.model.set('participantType', OCA.SpreedMe.app.USER);
+						} else {
+							self.model.set('participantType', OCA.SpreedMe.app.GUEST);
+						}
 						// When an attribute that affects the order of a
 						// collection is set the collection has to be explicitly
 						// sorted again.
@@ -259,7 +301,8 @@
 					participantId = this.model.get('userId'),
 					endpoint = '/participants';
 
-				if (this.model.get('participantType') === OCA.SpreedMe.app.GUEST) {
+				if (this.model.get('participantType') === OCA.SpreedMe.app.GUEST ||
+						this.model.get('participantType') === OCA.SpreedMe.app.GUEST_MODERATOR) {
 					participantId = this.model.get('sessionId');
 					endpoint += '/guests';
 				}
