@@ -24,7 +24,7 @@ var spreedPeerConnectionTable = [];
 			currentUsersNo = 1;
 		}
 
-		var $appContentElement = $('#app-content, #talk-sidebar'),
+		var $appContentElement = $(OCA.SpreedMe.app.mainCallElementSelector),
 			participantsClass = 'participants-' + currentUsersNo,
 			hadScreensharing = $appContentElement.hasClass('screensharing'),
 			hadSidebar = $appContentElement.hasClass('with-app-sidebar');
@@ -314,12 +314,6 @@ var spreedPeerConnectionTable = [];
 		OCA.SpreedMe.webrtc = webrtc;
 
 		OCA.SpreedMe.webrtc.startMedia = function (token) {
-			app.setEmptyContentMessage(
-				'icon-video-off',
-				t('spreed', 'Waiting for camera and microphone permissions'),
-				t('spreed', 'Please, give your browser access to use your camera and microphone in order to use this app.')
-			);
-
 			webrtc.joinCall(token);
 		};
 
@@ -363,7 +357,6 @@ var spreedPeerConnectionTable = [];
 				var user = usersInCallMapping[id];
 				if (user && !userHasStreams(user)) {
 					console.log("User has no stream", id);
-					return;
 				}
 
 				// Indicator for username
@@ -1031,23 +1024,13 @@ var spreedPeerConnectionTable = [];
 				console.log('Error while accessing microphone & camera: ', error.message || error.name);
 			}
 
-			app.startWithoutLocalMedia(webrtc.webrtc.isAudioEnabled(), webrtc.webrtc.isVideoEnabled());
+			app.startWithoutLocalMedia({audio: false, video: false});
 			OC.Notification.show(message, {
 				type: 'error',
 				timeout: 15,
 			});
-			app.restoreEmptyContent();
 		});
 
-		if(!OCA.SpreedMe.webrtc.capabilities.support) {
-			console.log('WebRTC not supported');
-			OCA.SpreedMe.app.setEmptyContentMessage(
-				'icon-video-off',
-				t('spreed', 'WebRTC is not supported in your browser :-/'),
-				t('spreed', 'Please use a different browser like Firefox or Chrome')
-			);
-		}
-
 		OCA.SpreedMe.webrtc.on('channelOpen', function(channel) {
 			console.log('%s datachannel is open', channel.label);
 		});
@@ -1137,6 +1120,8 @@ var spreedPeerConnectionTable = [];
 
 		// a peer was removed
 		OCA.SpreedMe.webrtc.on('videoRemoved', function(video, peer) {
+			var screens;
+
 			if (peer) {
 				if (peer.type === 'video') {
 					// a removed peer can't speak anymore ;)
@@ -1162,7 +1147,7 @@ var spreedPeerConnectionTable = [];
 				// handled differently.
 				OCA.SpreedMe.webrtc.emit('localScreenStopped');
 
-				var screens = document.getElementById('screens');
+				screens = document.getElementById('screens');
 				var localScreenContainer = document.getElementById('localScreenContainer');
 				if (screens && localScreenContainer) {
 					screens.removeChild(localScreenContainer);
@@ -1172,9 +1157,10 @@ var spreedPeerConnectionTable = [];
 			}
 
 			// Check if there are still some screens
-			if (!document.getElementById('screens').hasChildNodes()) {
+			screens = document.getElementById('screens');
+			if (!screens || !screens.hasChildNodes()) {
 				screenSharingActive = false;
-				$('#app-content, #talk-sidebar').removeClass('screensharing');
+				$(OCA.SpreedMe.app.mainCallElementSelector).removeClass('screensharing');
 				if (unpromotedSpeakerId) {
 					OCA.SpreedMe.speakers.switchVideoToId(unpromotedSpeakerId);
 					unpromotedSpeakerId = null;
@@ -1200,7 +1186,7 @@ var spreedPeerConnectionTable = [];
 			OCA.SpreedMe.speakers.unpromoteLatestSpeaker();
 
 			screenSharingActive = true;
-			$('#app-content, #talk-sidebar').addClass('screensharing');
+			$(OCA.SpreedMe.app.mainCallElementSelector).addClass('screensharing');
 
 			var screens = document.getElementById('screens');
 			if (screens) {
@@ -1246,15 +1232,17 @@ var spreedPeerConnectionTable = [];
 			var signaling = OCA.SpreedMe.app.signaling;
 
 			var currentSessionId = signaling.getSessionid();
-			OCA.SpreedMe.webrtc.getPeers(null, 'video').forEach(function (existingPeer) {
-				if (existingPeer.id === currentSessionId) {
+			for (var sessionId in usersInCallMapping) {
+				if (!usersInCallMapping.hasOwnProperty(sessionId)) {
+					continue;
+				} else if (sessionId === currentSessionId) {
 					// Running with MCU, no need to create screensharing
 					// subscriber for client itself.
-					return;
+					continue;
 				}
 
-				createScreensharingPeer(signaling, existingPeer.id);
-			});
+				createScreensharingPeer(signaling, sessionId);
+			}
 		});
 
 		OCA.SpreedMe.webrtc.on('localScreenStopped', function() {
@@ -1364,31 +1352,6 @@ var spreedPeerConnectionTable = [];
 				OCA.SpreedMe.speakers.updateVideoContainerDummy(data.id);
 			}
 		});
-
-		OCA.SpreedMe.webrtc.on('localStream', function() {
-			console.log('localStream');
-			if (!app.videoWasEnabledAtLeastOnce) {
-				app.videoWasEnabledAtLeastOnce = true;
-			}
-
-			//Reset audio and video control panel
-			app.hasAudio();
-			app.hasVideo();
-
-			if (!app.videoDisabled) {
-				app.enableVideo();
-			}
-
-			if (!OCA.SpreedMe.webrtc.webrtc.isAudioEnabled()) {
-				app.disableAudio();
-				app.hasNoAudio();
-			}
-
-			if (!OCA.SpreedMe.webrtc.webrtc.isVideoEnabled()) {
-				app.disableVideo();
-				app.hasNoVideo();
-			}
-		});
 	}
 
 	OCA.SpreedMe.initWebRTC = initWebRTC;
