@@ -11,27 +11,14 @@ OC.L10N.register(
     "UDP only" : "kun UDP",
     "TCP only" : "kun TCP",
     "TURN server protocols" : "TURN server protokoller ",
-    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
-    "Screensharing options" : "Skærmdeling indstillinger",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
-    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
-    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
     "Participants" : "Deltagere",
     "Chat" : "Chat",
     "Talk" : "Snak",
-    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
-    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
-    "Enable screensharing" : "Slå skærmdeling til",
     "Copy" : "Kopiér",
     "Copied!" : "Kopieret!",
     "Not supported!" : "Ikke understøttet",
     "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
     "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
-    "Share screen" : "Del skærm",
-    "Show your screen" : "Vis din skærm",
-    "Stop screensharing" : "Stop skærmdeling",
     "Please enter the password for this call" : "Indtast venligst password for dette opkald",
     "Password required" : "Password påkrævet",
     "Password" : "Password",
@@ -51,23 +38,36 @@ OC.L10N.register(
     "[Unknown user name]" : "[Ukendt brugernavn] ",
     "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
     "Edit" : "Rediger",
+    "No other people in this call" : "Ingen andre deltager i dette opkald",
+    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
+    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
+    "Share this link to invite others!" : "Del dette link for at invitere andre!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
+    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
+    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
+    "Disable video" : "Deaktiver video",
+    "Share screen" : "Del skærm",
+    "Show your screen" : "Vis din skærm",
+    "Stop screensharing" : "Stop skærmdeling",
+    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
+    "Screensharing options" : "Skærmdeling indstillinger",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
+    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
+    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
+    "Enable screensharing" : "Slå skærmdeling til",
     "moderator" : "modeator",
     "Demote from moderator" : "Degrader fra moderator",
     "Promote to moderator" : "Forfrem til moderator",
     "Remove participant" : "Fjern deltager",
-    "No other people in this call" : "Ingen andre deltager i dette opkald",
-    "Share this link to invite others!" : "Del dette link for at invitere andre!",
     "Close" : "Luk",
-    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
-    "Disable video" : "Deaktiver video",
     "Show screen" : "Vis skærm",
     "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
     "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
     "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
-    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
     "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
-    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
     "{participantName}'s screen" : "{participantName}s skærm",
     "Guest's screen" : "Gæsts skærm",
     "Your screen" : "Din skærm",
@@ -94,38 +94,8 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
     "TURN server" : "TURN server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
-    "Video calls" : "Video opkald",
     "(group)" : "(gruppe)",
-    "New public call" : "Nyt offentligt opkald",
-    "Looking great today! :)" : "Du ser godt ud idag! :)",
-    "Time to call your friends" : "Påtide at ringe til dine venner",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Du kan sætte dit navn i det øverste højre hjørne af denne side, så andre deltagere bedre kan identificere dig.",
-    "This call has ended" : "Opkaldet er afsluttet",
-    "Saving failed" : "Kunne ikke gemme",
-    "Add person" : "Tilføj person",
     "and you" : "og dif",
-    "Please adjust your configuration" : "Justér venligst dine konfigurationer",
-    "{actor} invited you to a private call" : "{actor} inviterede dig til et privat opkald",
-    "{actor} invited you to a group call" : "{actor} inviterede dig til et gruppe opkald.",
-    "{actor} invited you to the call {call}" : "{actor} inviterede dig til opkaldet {call}",
-    "You were invited to a <strong>video call</strong>" : "Du er blevet inviteret til et <strong>video opkald</strong>",
-    "Video call" : "Video opkald",
-    "Invalid format, must be stunserver:port." : "Forkert format, skal være stunserver:port.",
-    "Invalid port specified." : "Ugyldig port",
-    "Invalid protocols specified." : "Ugyldig protokol",
-    "%s invited you to a private call" : "%s er inviteret til dit private opkald",
-    "{user} invited you to a private call" : "{user} er inviteret til dit private opkald",
-    "%s invited you to a group call: %s" : "%s inviterede dig til et gruppe opkald: %s",
-    "{user} invited you to a group call: {call}" : "{user} inviterede dig til et gruppe opkald: {call}",
-    "%s invited you to a group call" : "%s inviterede dig til et gruppe opkald",
-    "{user} invited you to a group call" : "{user} inviterede dig til et gruppe opkald",
-    "Fullscreen" : "Fuldskærm",
-    "Mute audio" : "Mute lyd",
-    "Smile in 3… 2… 1!" : "Smil om 3... 2... 1!",
-    "Choose person …" : "Vælg person ...",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN serveren er nødvendig for at deltagerne kan forbinde til opkaldene. TURN serveren sikre at forbindelsen virker, selv gennem firewalls.",
-    "STUN server" : "STUN server",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN serveren bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …"
