@@ -11,25 +11,14 @@ OC.L10N.register(
     "UDP only" : "UDP bakarrik",
     "TCP only" : "TCP bakarrik",
     "TURN server protocols" : "TURN zerbitzari protokoloak",
-    "Screensharing is not supported by your browser." : "Zure nabigatzaileak ez du pantaila partekatzea onartzen",
-    "Screensharing requires the page to be loaded through HTTPS." : "Pantaila partekatzeko webguneak  HTTPS erabili behar du. ",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Pantaila partekatzea Firefox 52 edo berriagoekin bakarrik funtzionatzen du",
-    "Screensharing extension is required to share your screen." : "Pantaila partekatzeko pantailak partekatzeko luzapena instalatu behar da.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Pantaila partekatzeko Firefox edo Chrome erabil ezazu mesedez.",
-    "An error occurred while starting screensharing." : "Pantaila partekatzean errore bat egon da.",
     "Participants" : "Partehartzaileak",
     "Chat" : "Chat",
     "Talk" : "Hitzaldi",
-    "Waiting for {participantName} to join the call …" : "{participantName}-ri itxoitzen deira gehitzeko",
-    "Waiting for others to join the call …" : "Besteek deira gehitzera itxoiten...",
     "Copy" : "Kopiatu",
     "Copied!" : "Kopiatuta!",
     "Not supported!" : "Euskarririk gabe!",
     "Press ⌘-C to copy." : "Kopiatzeko ⌘-C to sakatu.",
     "Press Ctrl-C to copy." : "Kopiatzeko Ktrl -C sakatu.",
-    "Share screen" : "Pantaila partekatu",
-    "Show your screen" : "Idazmahaia erakutsi",
-    "Stop screensharing" : "Pantaila partekatzeari utzi",
     "Please enter the password for this call" : "Dei honetarako pasahitza sartu mesedez",
     "Password required" : "Pasahitza beharrezkoa",
     "Password" : "Pasahitza",
@@ -54,23 +43,34 @@ OC.L10N.register(
     "Yesterday" : "Atzo",
     "Error occurred while sending message" : "Mezua bidaltzean errorea egon da",
     "Edit" : "Editatu",
+    "No other people in this call" : "Ez dago jenderik dei honetan",
+    "Waiting for {participantName} to join the call …" : "{participantName}-ri itxoitzen deira gehitzeko",
+    "Waiting for others to join the call …" : "Besteek deira gehitzera itxoiten...",
+    "WebRTC is not supported in your browser :-/" : "Zure nabigatzaileak ez du WebRTC onartzen :-/",
+    "Please use a different browser like Firefox or Chrome" : "Firefox edo Chrome bezalako nabigatzailea erabili",
+    "Waiting for camera and microphone permissions" : "Kamera eta mikrofonoaren baimeneni itxoiten",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "App hau erabiltzeko mesedez, nabigatzaileari kamara eta mikroa erabiltzeko baimena eman. ",
+    "Disable video" : "Bideoa desgaitu",
+    "Share screen" : "Pantaila partekatu",
+    "Show your screen" : "Idazmahaia erakutsi",
+    "Stop screensharing" : "Pantaila partekatzeari utzi",
+    "Screensharing is not supported by your browser." : "Zure nabigatzaileak ez du pantaila partekatzea onartzen",
+    "Screensharing requires the page to be loaded through HTTPS." : "Pantaila partekatzeko webguneak  HTTPS erabili behar du. ",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Pantaila partekatzea Firefox 52 edo berriagoekin bakarrik funtzionatzen du",
+    "Screensharing extension is required to share your screen." : "Pantaila partekatzeko pantailak partekatzeko luzapena instalatu behar da.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Pantaila partekatzeko Firefox edo Chrome erabil ezazu mesedez.",
+    "An error occurred while starting screensharing." : "Pantaila partekatzean errore bat egon da.",
     "moderator" : "moderatzailea",
     "Demote from moderator" : "Moderatzailetik degradatua",
     "Promote to moderator" : "Moderatzaile bihurtu zara",
     "Remove participant" : "Partehartzailea borratu",
-    "No other people in this call" : "Ez dago jenderik dei honetan",
     "Close" : "Itxi",
-    "Waiting for camera and microphone permissions" : "Kamera eta mikrofonoaren baimeneni itxoiten",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "App hau erabiltzeko mesedez, nabigatzaileari kamara eta mikroa erabiltzeko baimena eman. ",
-    "Disable video" : "Bideoa desgaitu",
     "Show screen" : "Erakutsi pantaila",
     "Enable video" : "Aktibatu bideoa",
     "Access to microphone & camera is only possible with HTTPS" : "Kamara eta mikrofonoak atzitzeko modu bakarra HTTPS bidez da",
     "Access to microphone & camera was denied" : "Kamara eta mikrora sarrera debekatua",
     "WebRTC is not supported in your browser" : "Zure nabigatzaileak ez du WebRTC onartzen",
-    "Please use a different browser like Firefox or Chrome" : "Firefox edo Chrome bezalako nabigatzailea erabili",
     "Error while accessing microphone & camera" : "Mikrofonoa eta kamara atzitzean errorea",
-    "WebRTC is not supported in your browser :-/" : "Zure nabigatzaileak ez du WebRTC onartzen :-/",
     "{participantName}'s screen" : "{participantName}-aren pantaila",
     "Guest's screen" : "Gonbidatuaren pantaila",
     "Your screen" : "Zure pantaila",
@@ -94,37 +94,7 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN zerbitzariak router baten atzean dauden erabiltzaileen IP helbideak jakiteko erabiltzen da.",
     "TURN server" : "TURN zerbitzaria",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN zerbitzariak  firewall baten atzean dauden partehartzaileen trafikoa proxy bidez eramateko erabiltzen da",
-    "Video calls" : "Bideo deiak",
     "(group)" : "(taldea)",
-    "New public call" : "Dei publiko berria",
-    "Looking great today! :)" : "Itxura ederra gaur! :)",
-    "Time to call your friends" : "Lagunak deitzeko garaia heldu da",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Pantailaren goi eskubian zure izena jar dezakezu, beste partaideek hobeto identifikatzeko.",
-    "This call has ended" : "Deia bukatu da",
-    "Saving failed" : "Gordetzean errorea",
-    "Add person" : "Pertsona gehitu",
-    "and you" : "eta zu",
-    "Please adjust your configuration" : "Konfigurazioa zehaztu",
-    "{actor} invited you to a private call" : "{actor} dei pribatu batera gonbidatu zaitu",
-    "{actor} invited you to a group call" : "{actor} dei publiko batera gonbidatu zaitu",
-    "{actor} invited you to the call {call}" : "{actor} {call } deira gonbidatu zaitu",
-    "You were invited to a <strong>video call</strong>" : "<strong>bideo deia </strong> gonbidatua izan zara",
-    "Video call" : "Bideo deia",
-    "Invalid format, must be stunserver:port." : "Formatu desegokia, stunzerb:portua izan behar du",
-    "Invalid port specified." : "Portu ezegokia jarri da",
-    "Invalid protocols specified." : "Protokolo ezegokiak jarri dira",
-    "%s invited you to a private call" : "%s- dei pribatu batera gonbidatu zaitu",
-    "{user} invited you to a private call" : "{user}-rek dei pribatu batera gonbidatu zaitu",
-    "%s invited you to a group call: %s" : "%s-k %s talde deira gonbidatu zaitu",
-    "{user} invited you to a group call: {call}" : "{user}-k {call} talde deira gonbidatu zaitu",
-    "%s invited you to a group call" : "%s talde deira gonbidatu zaitu",
-    "{user} invited you to a group call" : "{user} talde deira gonbidatu zaitu",
-    "Fullscreen" : "Pantaila osoa",
-    "Mute audio" : "Audioa ixildu",
-    "Smile in 3… 2… 1!" : "parre egin 3...2...1!",
-    "Choose person …" : "Pertsona hautatu",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN zerbitzaria beharrezkoa da deiak konektatzeko. TURN zerbitzariak konexioa funtzionatzen duela bermatzen du, nahiz eta firewall bat egon.",
-    "STUN server" : "STUN zerbitzaria",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN zerbitzaria router baten atzean dauden erabiltzaileen IP helbideak jakiteko balio du"
+    "and you" : "eta zu"
 },
 "nplurals=2; plural=(n != 1);");
