@@ -18,39 +18,19 @@ OC.L10N.register(
     "New group conversation" : "Uusi ryhmäkeskustelu",
     "{name} (public)" : "{name} (julkinen)",
     "New conversation …" : "Uusi keskustelu…",
-    "Screensharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
-    "Screensharing options" : "Näytönjakamisen valinnat",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
-    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
-    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
     "Participants" : "Osallistujat",
     "Chat" : "Keskustelu",
     "Talk" : "Puhe",
-    "Waiting for {participantName} to join the call …" : "Odotetaan henkilön {participantName} liittymistä puheluun...",
-    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
     "Fullscreen (f)" : "Koko näytön tila (f)",
-    "Mute audio (m)" : "Mykistä äänet (m)",
-    "Unmute audio (m)" : "Palauta äänet (m)",
-    "No audio" : "Ei ääntä",
-    "Disable video (v)" : "Poista video käytöstä (v)",
-    "Enable video (v)" : "Ota video käyttöön (v)",
     "Set your name in the chat window so other participants can identify you better." : "Aseta nimesi keskusteluikkunassa, jotta muut osalliset tunnistavat sinut.",
-    "No Camera" : "Ei kameraa",
-    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
     "Copy" : "Kopioi",
     "Copied!" : "Kopioitu!",
     "Not supported!" : "Ei tuettu!",
     "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
-    "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
-    "This conversation has ended" : "Tämä keskustelu on päättynyt",
+    "Share" : "Jaa",
     "Request password" : "Pyydä salasana",
-    "Share screen" : "Jaa näyttö",
-    "Show your screen" : "Näytä oma näyttösi",
-    "Stop screensharing" : "Lopeta näytön jakaminen",
     "Error requesting the password." : "Virhe pyytäessä salasanaa.",
     "Please enter the password for this call" : "Anna salasana tälle puhelulle",
     "Password required" : "Salasana vaaditaan",
@@ -83,10 +63,41 @@ OC.L10N.register(
     "File to share" : "Jaettava tiedosto",
     "Error while sharing" : "Virhe jaettaessa",
     "Edit" : "Muokkaa",
+    "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
+    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
+    "Waiting for {participantName} to join the call …" : "Odotetaan henkilön {participantName} liittymistä puheluun...",
+    "Waiting for others to join the call …" : "Odotetaan muiden liittymistä puheluun...",
+    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
+    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC ei ole tuettuna selaimessasi :-/",
+    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
+    "Waiting for camera and microphone permissions" : "Odotetaan käyttöoikeuden myöntämistä kameralle ja mikrofonille",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Anna selaimellesi oikeus käyttää kameraa ja mikrofonia käyttääksesi tätä sovellusta.",
+    "This conversation has ended" : "Tämä keskustelu on päättynyt",
+    "Disable video" : "Poista video käytöstä",
+    "Share screen" : "Jaa näyttö",
+    "Show your screen" : "Näytä oma näyttösi",
+    "Stop screensharing" : "Lopeta näytön jakaminen",
+    "Unmute audio (m)" : "Palauta äänet (m)",
+    "Mute audio (m)" : "Mykistä äänet (m)",
+    "No audio" : "Ei ääntä",
+    "Enable video (v)" : "Ota video käyttöön (v)",
+    "Disable video (v)" : "Poista video käytöstä (v)",
+    "No Camera" : "Ei kameraa",
+    "Screensharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
+    "Screensharing options" : "Näytönjakamisen valinnat",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
+    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
+    "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
+    "Enable screensharing" : "Ota käyttöön näytönjakaminen",
     "moderator" : "moderaattori",
     "Demote from moderator" : "Alenna moderaattorista",
     "Promote to moderator" : "Ylennä moderaattoriksi",
     "Remove participant" : "Poista osallistuja",
+    "Error while removing user from room" : "Virhe poistaessa käyttäjää huoneesta",
     "Add participant …" : "Lisää osallistuja…",
     "Favorited" : "Lisätty suosikkeihin",
     "Remove from favorites" : "Poista suosikeista",
@@ -96,23 +107,14 @@ OC.L10N.register(
     "Never notify" : "Älä ilmoita koskaan",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
-    "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
-    "You can invite others in the participant tab of the sidebar" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta",
-    "Share this link to invite others!" : "Jaa tämä linkki kutsuaksesi muita!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Voit kutsua muita sivupalkissa olevan Osallistujat-välilehden kautta tai jakamalla tämän linkin!",
     "Close" : "Sulje",
-    "Waiting for camera and microphone permissions" : "Odotetaan käyttöoikeuden myöntämistä kameralle ja mikrofonille",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Anna selaimellesi oikeus käyttää kameraa ja mikrofonia käyttääksesi tätä sovellusta.",
-    "Disable video" : "Poista video käytöstä",
     "Show screen" : "Näytä näyttö",
     "Enable video" : "Käytä videota",
     "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
     "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
     "Access to microphone & camera was denied" : "Yhteys mikrofoniin ja kameraan estettiin",
     "WebRTC is not supported in your browser" : "WebRTC ei ole tuettuna selaimessasi",
-    "Please use a different browser like Firefox or Chrome" : "Käytä jotain toista selainta, kuten Firefoxia tai Chromea",
     "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
-    "WebRTC is not supported in your browser :-/" : "WebRTC ei ole tuettuna selaimessasi :-/",
     "{participantName}'s screen" : "Henkilön {participantName} näyttö",
     "Guest's screen" : "Vieraan näyttö",
     "Your screen" : "Sinun näyttösi",
@@ -164,6 +166,7 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
+    "Password request: %s" : "Salasanapyyntö: %s",
     "_%n other guest_::_%n other guests_" : ["%n muu vieras","%n muuta vierasta"],
     ", " : ",",
     "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
@@ -202,38 +205,8 @@ OC.L10N.register(
     "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
-    "Video calls" : "Videopuhelut",
     "(group)" : "(ryhmä)",
-    "New public call" : "Uusi julkinen puhelu",
-    "Looking great today! :)" : "Näytät hyvältä tänään! :)",
-    "Time to call your friends" : "Aika soittaa ystävillesi",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Voit asettaa nimesi sivun oikeassa yläkulmassa, jotta muut osallistujat tunnistavat sinut paremmin.",
-    "This call has ended" : "Puhelu päättyi",
-    "Saving failed" : "Tallennus epäonnistui",
-    "Add person" : "Lisää henkilö",
     "and you" : "ja sinä",
-    "Please adjust your configuration" : "Määrittele kokoonpanosi",
-    "{actor} invited you to a private call" : "{actor} kutsui sinut yksityispuheluun",
-    "{actor} invited you to a group call" : "{actor} kutsui sinut ryhmäpuheluun",
-    "{actor} invited you to the call {call}" : "{actor} kutsui sinut puheluun {call}",
-    "You were invited to a <strong>video call</strong>" : "Sinut kutsuttiin <strong>videopuheluun</strong>",
-    "Video call" : "Videopuhelu",
-    "Invalid format, must be stunserver:port." : "Virheellinen muoto, osoitteen tulee olla muodossa stunpalvelin:portti.",
-    "Invalid port specified." : "Porttimääritys on virheellinen.",
-    "Invalid protocols specified." : "Protokollamääritykset ovat virheelliset.",
-    "%s invited you to a private call" : "%s kutsui sinut yksityispuheluun",
-    "{user} invited you to a private call" : "{user} kutsui sinut yksityispuheluun",
-    "%s invited you to a group call: %s" : "%s kutsui sinut ryhmäpuheluun: %s",
-    "{user} invited you to a group call: {call}" : "{user} kutsui sinut ryhmäpuheluun: {call}",
-    "%s invited you to a group call" : "%s kutsui sinut ryhmäpuheluun",
-    "{user} invited you to a group call" : "{user} kutsui sinut ryhmäpuheluun",
-    "Fullscreen" : "Koko näyttö",
-    "Mute audio" : "Mykistä ääni",
-    "Smile in 3… 2… 1!" : "Hymyile, 3... 2... 1!",
-    "Choose person …" : "Valitse henkilö...",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN-palvelin on välttämätön, jotta osallistujat voivat yhdistää puheluihin. TURN-palvelin varmistaa, että yhteys toimii myös palomuurien läpi.",
-    "STUN server" : "STUN-palvelin",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN-palvelinta käytetään määrittämään julkinen osoite reitittimen takana oleville osallistujille.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …",
@@ -247,6 +220,7 @@ OC.L10N.register(
     "A guest mentioned you in a group conversation: %s" : "Vieras mainitsi sinut ryhmäkeskustelussa: %s",
     "A guest mentioned you in a group conversation: {call}" : "Vieras mainitsi sinut ryhmäkeskustelussa: {call}",
     "A guest mentioned you in a group conversation" : "Vieras mainitsi sinut ryhmäkeskustelussa",
+    "The TURN server settings are valid." : "TURN-palvelimen asetukset ovat kelvolliset.",
     "{email} requested the password to access a share" : "{email} pyysi salasanaa käyttääkseen jakoa"
 },
 "nplurals=2; plural=(n != 1);");
