@@ -12,31 +12,20 @@ OC.L10N.register(
     "TCP only" : "csak TCP",
     "TURN server protocols" : "TURN kiszolgáló protokollok",
     "New public conversation" : "Új nyilvános beszélgetés",
+    "New group conversation" : "Új csoport beszélgetés",
     "New conversation …" : "Új beszélgetés …",
-    "Screensharing is not supported by your browser." : "A böngésződ nem támogatja a képernyőmegosztást.",
-    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz HTTPS szükséges.",
-    "Screensharing options" : "Képernyő megosztás beállításai",
-    "Sharing your screen only works with Firefox version 52 or newer." : "A képernyőmegosztás 52-es és magasabb Firefox verziótól érhető el.",
-    "Screensharing extension is required to share your screen." : "Képernyőmegosztó bővítményre van szükség.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Kérjük használj más böngészőt, például Firefox-ot vagy Chrome-ot, a képernyőmegosztáshoz.",
-    "An error occurred while starting screensharing." : "Hiba lépett fel a képernyőmegosztás közben.",
     "Participants" : "Résztvevők",
     "Chat" : "Csevegés",
     "Talk" : "Beszélgetés",
-    "Waiting for {participantName} to join the call …" : "Várakozunk, hogy {participantName} csatlakozzon a híváshoz...",
-    "Waiting for others to join the call …" : "Várakozunk, hogy mások csatlakozzanak a híváshoz...",
     "Exit fullscreen (f)" : "Kilépés a teljes képernyős módból (f)",
-    "Mute audio (m)" : "Audio elnémítása (m)",
-    "No Camera" : "Nincs kamera",
-    "Enable screensharing" : "Képernyő megosztás engedélyezése",
+    "Fullscreen (f)" : "Teljes képernyő (f)",
     "Copy" : "Másol",
     "Copied!" : "Másolva!",
     "Not supported!" : "Nem támogatott!",
     "Press ⌘-C to copy." : "Nyomj ⌘-C-t a másoláshoz.",
     "Press Ctrl-C to copy." : "Nyomj Ctrl-C-t a másoláshoz.",
-    "Share screen" : "Képernyő megosztása",
-    "Show your screen" : "Képernyőd megosztása",
-    "Stop screensharing" : "Képernyő megosztás befejezése",
+    "Request password" : "Jelszó kérése",
+    "Error requesting the password." : "Hiba a jelszó kérésekor.",
     "Please enter the password for this call" : "Kérlek adj meg egy jelszót ehhez a híváshoz",
     "Password required" : "Jelszó szükséges",
     "Password" : "Jelszó",
@@ -44,10 +33,12 @@ OC.L10N.register(
     "Submit" : "Küldés",
     "Leave call" : "Hívás elhagyása",
     "Join call" : "Csatlakozás híváshoz",
+    "Start call" : "Hívás indítása",
     "Share link" : "Megosztás hivatkozással",
     "Change password" : "Jelszó módosítása",
     "Set password" : "Jelszó beállítása",
     "Name" : "Név",
+    "Conversation name" : "Beszélgetés neve",
     "Rename" : "Átnevezés",
     "Copy link" : "Hivatkozás másolása",
     "Conversation with {name}" : "Beszélgetés vele: {name}",
@@ -55,6 +46,7 @@ OC.L10N.register(
     "Link copied!" : "Hivatkozás másolva!",
     "You" : "Te",
     "No messages yet, start the conversation!" : "Még nincs üzenet, kezdeményezz beszélgetést!",
+    "New message …" : "Új üzenet ...",
     "Send" : "Küld",
     "Guest" : "Vendég",
     "[Unknown user name]" : "[ismeretlen felhasználónév]",
@@ -62,26 +54,52 @@ OC.L10N.register(
     "Yesterday" : "Tegnap",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "Hiba az üzenetküldés közben",
+    "File to share" : "Fájl megosztása",
+    "Error while sharing" : "Hiba megosztás közben",
     "Edit" : "Szerkesztés",
+    "Join a conversation or start a new one" : "Csatlakozz egy társalgásba vagy indíts egy újat",
+    "No other people in this call" : "Nincs más ebben a hívásban",
+    "Waiting for {participantName} to join the call …" : "Várakozunk, hogy {participantName} csatlakozzon a híváshoz...",
+    "Waiting for others to join the call …" : "Várakozunk, hogy mások csatlakozzanak a híváshoz...",
+    "You can invite others in the participant tab of the sidebar" : "Az oldalsávon található „közreműködő” fülön lehet másokat meghívni",
+    "Share this link to invite others!" : "Oszd meg ezt a linket mások meghívásához!",
+    "WebRTC is not supported in your browser :-/" : "A böngésződ nem támogatja a WebRTC-t :-/",
+    "Please use a different browser like Firefox or Chrome" : "Kérlek használj másik böngészőt pl Firefoxot vagy Chrome-ot",
+    "Waiting for camera and microphone permissions" : "Várakozás kamera és mikrofon engedélyezésre",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Kérlek engedélyezd a kamera és mikrofon elérést az app használatához.",
+    "Disable video" : "Videó kikapcsolása",
+    "Share screen" : "Képernyő megosztása",
+    "Show your screen" : "Képernyőd megosztása",
+    "Stop screensharing" : "Képernyő megosztás befejezése",
+    "Unmute audio (m)" : "Hang engedélyezése (m)",
+    "Mute audio (m)" : "Audio elnémítása (m)",
+    "No audio" : "Nincs hang",
+    "Enable video (v)" : "Videó engedélyezése (v)",
+    "Disable video (v)" : "Videó kikapcsolása (v)",
+    "No Camera" : "Nincs kamera",
+    "Screensharing is not supported by your browser." : "A böngésződ nem támogatja a képernyőmegosztást.",
+    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz HTTPS szükséges.",
+    "Screensharing options" : "Képernyő megosztás beállításai",
+    "Sharing your screen only works with Firefox version 52 or newer." : "A képernyőmegosztás 52-es és magasabb Firefox verziótól érhető el.",
+    "Screensharing extension is required to share your screen." : "Képernyőmegosztó bővítményre van szükség.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Kérjük használj más böngészőt, például Firefox-ot vagy Chrome-ot, a képernyőmegosztáshoz.",
+    "An error occurred while starting screensharing." : "Hiba lépett fel a képernyőmegosztás közben.",
+    "Enable screensharing" : "Képernyő megosztás engedélyezése",
     "moderator" : "moderátor",
     "Demote from moderator" : "lefokozás moderátorról",
     "Promote to moderator" : "Moderátorrá kinevezés",
     "Remove participant" : "Résztvevő eltávolítása",
+    "Add participant …" : "Résztvevő hozzáadása ...",
+    "Add to favorites" : "Hozzáadás a kedvencekhez ",
+    "Leave conversation" : "Kilépés a beszélgetésből",
     "Delete conversation" : "Beszélgetés törlése",
-    "No other people in this call" : "Nincs más ebben a hívásban",
-    "You can invite others in the participant tab of the sidebar" : "Az oldalsávon található „közreműködő” fülön lehet másokat meghívni",
-    "Share this link to invite others!" : "Oszd meg ezt a linket mások meghívásához!",
     "Close" : "Bezár",
-    "Waiting for camera and microphone permissions" : "Várakozás kamera és mikrofon engedélyezésre",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Kérlek engedélyezd a kamera és mikrofon elérést az app használatához.",
-    "Disable video" : "Videó kikapcsolása",
     "Show screen" : "Képernyőd mutatása",
     "Access to microphone & camera is only possible with HTTPS" : "A mikrofon és a kamera hozzáférése csak HTTPS-en lehetséges",
+    "Please move your setup to HTTPS" : "Kérlek váltsd a konfigurációdat HTTPS-re",
     "Access to microphone & camera was denied" : "A kamera és a mikrofon hozzáférése letiltva",
     "WebRTC is not supported in your browser" : "A böngésződ nem támogatja a WebRTC-t",
-    "Please use a different browser like Firefox or Chrome" : "Kérlek használj másik böngészőt pl Firefoxot vagy Chrome-ot",
     "Error while accessing microphone & camera" : "Hiba a kamera és a mikrofon hozzáférésekor",
-    "WebRTC is not supported in your browser :-/" : "A böngésződ nem támogatja a WebRTC-t :-/",
     "{participantName}'s screen" : "{participantName} képernyője",
     "Guest's screen" : "Vendég képernyője",
     "Your screen" : "Te képernyőd",
@@ -95,12 +113,19 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["még %n","még %n"],
     "{actor} invited you to {call}" : "{actor} meghívott ide: {call}",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Meghívtak egy <strong>beszélgető </strong> szobába vagy volt egy <strong>hívásod</strong>",
+    "You created the conversation" : "Beszélgetést hoztál létre",
+    "You started a call" : "Hívást kezdeményeztél",
+    "{actor} joined the call" : "{actor} bekapcsolódott a hívásba",
+    "You joined the call" : "Csatlakoztál a híváshoz",
+    "You left the call" : "Kiléptél a hívásból",
+    "You shared a file which is no longer available" : "Megosztottál egy fájlt, amelyik többé nem elérhető",
     "Talk to %s" : "Beszélgetés vele: %s",
     "_%n other guest_::_%n other guests_" : ["%n további vendég","%n további vendég"],
     ", " : ", ",
     "{user} wants to talk with you" : "{user} beszélni szeretne veled",
     "A group call has started in {call}" : "Csoportos hívás kezdődött itt: {call}",
     "A group call has started" : "Csoportos hívás kezdődött",
+    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátum YYYY-MM-DD formátumú kell legyen",
     "This call is password-protected" : "Ez a hívás jelszóval védett",
     "The password is wrong. Try again." : "Hibás jelszó, próbáld újra.",
     "Signaling server" : "Jelző szerver",
@@ -109,38 +134,10 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "Egy STUN szervert használunk a router mögötti résztvevők IP címének megállapítására.",
     "TURN server" : "TURN kiszolgáló",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "A TURN szervert használjuk a proxyként a tűzfal mögötti felhasználókhoz.",
-    "Video calls" : "Videó hívások",
+    "Android app" : "Android alkalmazás",
+    "iOS app" : "iOS alkalmazás",
     "(group)" : "(csoport)",
-    "New public call" : "Új nyilvános hívás",
-    "Looking great today! :)" : "Jól nézel ki ma! :)",
-    "Time to call your friends" : "Ideje a barátaidat felhívni",
-    "You can set your name on the top right of this page so other participants can identify you better." : "A jelenlegi oldal jobb felső sarkában állíthatod be a neved a könnyebb azonosíthatóság érdekében.",
-    "This call has ended" : "A hívás véget ért",
-    "Saving failed" : "Mentés sikertelen",
-    "Add person" : "Személy hozzáadás",
     "and you" : "és te",
-    "Please adjust your configuration" : "Kérlek állíts a konfiguráción",
-    "{actor} invited you to a private call" : "{actor} meghívott egy privát beszélgetésbe",
-    "{actor} invited you to a group call" : "{actor} meghívott egy csoportos beszélgetésbe",
-    "{actor} invited you to the call {call}" : "{actor} meghívott a(z) {call} beszélgetésbe",
-    "You were invited to a <strong>video call</strong>" : "Meghívtak egy <strong>videó hívásba</strong>",
-    "Video call" : "Videóhívás",
-    "Invalid format, must be stunserver:port." : "Érvénytelen formátum, ilyennek kell lennie: stunserver:port.",
-    "Invalid port specified." : "A megadott port érvénytelen",
-    "Invalid protocols specified." : "A megadott protokollok nem érvényesek.",
-    "%s invited you to a private call" : "%s meghívott egy privát beszélgetésre",
-    "{user} invited you to a private call" : "{user} meghívott egy privát beszélgetésre",
-    "%s invited you to a group call: %s" : "%s meghívott egy csoportos hívásba: %s",
-    "{user} invited you to a group call: {call}" : "{user} meghívott egy csoportos hívásba: {call}",
-    "%s invited you to a group call" : "%s meghívott egy csoportos beszélgetésre",
-    "{user} invited you to a group call" : "{user} meghívott egy csoportos beszélgetésre",
-    "Fullscreen" : "Teljes képernyő",
-    "Mute audio" : "Hang némítása",
-    "Smile in 3… 2… 1!" : "3… 2… 1... mosolyogj!",
-    "Choose person …" : "Válassz valakit ...",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "A STUN szerver azért szükséges, hogy mások is csatlakozhassanak a beszélgetésekhez. A TURN szerver a tűzfal mögötti felhasználók csatlakozását biztosítja.",
-    "STUN server" : "STUN kiszolgáló",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "A STUN szervert használunk a router mögötti résztvevők publikus IP címének megállapítására.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …",
@@ -150,6 +147,7 @@ OC.L10N.register(
     "{user} mentioned you in a group conversation" : "{user} megemlített téged egy csoportos beszélgetésben",
     "A guest mentioned you in a group conversation: %s" : "Egy vendég megemlített téged egy csoportos beszélgetésben: %s",
     "A guest mentioned you in a group conversation: {call}" : "Egy vendég megemlített téged egy csoportos beszélgetésben: {call}",
-    "A guest mentioned you in a group conversation" : "Egy vendég megemlített téged egy csoportos beszélgetésben"
+    "A guest mentioned you in a group conversation" : "Egy vendég megemlített téged egy csoportos beszélgetésben",
+    "The TURN server settings are valid." : "A TURN szerver beállítása érvényes."
 },
 "nplurals=2; plural=(n != 1);");
