@@ -18,37 +18,16 @@ OC.L10N.register(
     "New public conversation" : "新規公開会話",
     "New group conversation" : "新規会議",
     "New conversation …" : "新規公話",
-    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
-    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
-    "Screensharing options" : "画面共有オプション",
-    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
-    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
-    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
     "Participants" : "参加者",
     "Chat" : "チャット",
     "Talk" : "通話",
-    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
-    "Waiting for others to join the call …" : "参加を待っています …",
     "Exit fullscreen (f)" : "全画面終了 (f)",
     "Fullscreen (f)" : "全画面 (f)",
-    "Mute audio (m)" : "ミュート (m)",
-    "Unmute audio (m)" : "ミュート解除 (m)",
-    "No audio" : "音声なし",
-    "Disable video (v)" : "映像なし (v)",
-    "Enable video (v)" : "映像あり (v)",
-    "No Camera" : "カメラがありません",
-    "Enable screensharing" : "画面共有を有効にする",
     "Copy" : "コピー",
     "Copied!" : "コピーしました",
     "Not supported!" : "未対応",
     "Press ⌘-C to copy." : "⌘-C でコピーします。",
     "Press Ctrl-C to copy." : "Ctrl-C でコピーします。",
-    "Join a conversation or start a new one" : "会話に参加または開始する",
-    "This conversation has ended" : "会話は終了しました",
-    "Share screen" : "画面共有",
-    "Show your screen" : "自分の画面を表示",
-    "Stop screensharing" : "画面共有を停止",
     "Please enter the password for this call" : "この通話のパスワードを入力してください",
     "Password required" : "パスワードが必要です",
     "Password" : "パスワード",
@@ -77,28 +56,49 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "メッセージ送信中にエラーが発生しました",
     "Edit" : "編集",
+    "Join a conversation or start a new one" : "会話に参加または開始する",
+    "No other people in this call" : "この通話には誰もいません",
+    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
+    "Waiting for others to join the call …" : "参加を待っています …",
+    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
+    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
+    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
+    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
+    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
+    "This conversation has ended" : "会話は終了しました",
+    "Disable video" : "映像なし",
+    "Share screen" : "画面共有",
+    "Show your screen" : "自分の画面を表示",
+    "Stop screensharing" : "画面共有を停止",
+    "Unmute audio (m)" : "ミュート解除 (m)",
+    "Mute audio (m)" : "ミュート (m)",
+    "No audio" : "音声なし",
+    "Enable video (v)" : "映像あり (v)",
+    "Disable video (v)" : "映像なし (v)",
+    "No Camera" : "カメラがありません",
+    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
+    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
+    "Screensharing options" : "画面共有オプション",
+    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
+    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
+    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
+    "Enable screensharing" : "画面共有を有効にする",
     "moderator" : "モデレータ",
     "Demote from moderator" : "モデレータから降格",
     "Promote to moderator" : "モデレータに昇格",
     "Remove participant" : "参加者を削除",
     "Add participant …" : "参加者を追加",
     "Delete conversation" : "会話を削除",
-    "No other people in this call" : "この通話には誰もいません",
-    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
-    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
     "Close" : "閉じる",
-    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
-    "Disable video" : "映像なし",
     "Show screen" : "画面を表示",
     "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
     "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
     "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
     "WebRTC is not supported in your browser" : "このブラウザーはWebRTCをサポートしていません",
-    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
     "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
-    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
     "{participantName}'s screen" : "{participantName} の画面",
     "Guest's screen" : "ゲストの画面",
     "Your screen" : "自画面",
@@ -126,38 +126,8 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーは、ルーターを介した参加者のパブリックIPアドレスを決定するために使用されます。",
     "TURN server" : "TURNサーバー",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURNサーバーは参加者のファイアウォール越しの通信を中継します。",
-    "Video calls" : "ビデオ通話",
     "(group)" : "(グループ)",
-    "New public call" : "新規公開通話",
-    "Looking great today! :)" : "こんにちわ! ッ",
-    "Time to call your friends" : "ご友人と会話しませんか",
-    "You can set your name on the top right of this page so other participants can identify you better." : "このページの右上に自身の参加名を設定することで他の参加者があなたを認識しやすくできます。",
-    "This call has ended" : "この通話は終了しています",
-    "Saving failed" : "保存失敗",
-    "Add person" : "人を追加",
     "and you" : "と自分",
-    "Please adjust your configuration" : "設定を調整してください",
-    "{actor} invited you to a private call" : "{actor} からプライベート通話に招待されました",
-    "{actor} invited you to a group call" : "{actor} からグループ通話に招待されました",
-    "{actor} invited you to the call {call}" : "{actor} から通話 {call} に招待されました",
-    "You were invited to a <strong>video call</strong>" : "<strong>ビデオ通話</strong>に招待されました",
-    "Video call" : "ビデオ通話",
-    "Invalid format, must be stunserver:port." : "無効な形式です。stunserver:port としてください。",
-    "Invalid port specified." : "無効なポートが指定されました。",
-    "Invalid protocols specified." : "無効なプロトコルが指定されました。",
-    "%s invited you to a private call" : "%sからプライベート通話に招待されました ",
-    "{user} invited you to a private call" : "{user} からプライベート通話に招待されました",
-    "%s invited you to a group call: %s" : "%sからグループ通話に招待されました: %s ",
-    "{user} invited you to a group call: {call}" : "{user} からグループ通話に招待されました: {call}",
-    "%s invited you to a group call" : "%sからグループ通話に招待されました  ",
-    "{user} invited you to a group call" : "{user} からグループ通話に招待されました ",
-    "Fullscreen" : "全画面",
-    "Mute audio" : "音声なし",
-    "Smile in 3… 2… 1!" : "はいチーズ！",
-    "Choose person …" : "ユーザー選択 …",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUNサーバーは参加者の通話に必要です。TURNサーバーはファイアウォール経由の接続に使用されます。",
-    "STUN server" : "STUNサーバー",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーはルーターの背後にいる参加者のパブリックIPアドレスを決定するために使用されます。",
     "… %s" : "... %s",
     "%s …" : "%s ...",
     "… %s …" : "... %s ..."
