@@ -11,28 +11,14 @@ OC.L10N.register(
     "UDP only" : "მხოლოდ UDP",
     "TCP only" : "მხოლოდ TCP",
     "TURN server protocols" : "TURN სერვერის პროტოკოლები",
-    "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
-    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
-    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
-    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
-    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
-    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
     "Participants" : "მონაწილეები",
     "Chat" : "ჩეთი",
     "Talk" : "საუბარი",
-    "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
-    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
-    "No Camera" : "კამერა არაა",
-    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
     "Copy" : "კოპირება",
     "Copied!" : "კოპირებულია!",
     "Not supported!" : "არ არის მხარდაჭერილი!",
     "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
     "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
-    "Share screen" : "ეკრანის გაზიარება",
-    "Show your screen" : "თქვენი ეკრანის ჩვენება",
-    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
     "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
     "Password required" : "საჭიროა პაროლი",
     "Password" : "პაროლი",
@@ -59,24 +45,38 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "წერილის გაგზავნისას წარმოიშვა შეცდომა",
     "Edit" : "შეცვლა",
+    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
+    "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
+    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
+    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
+    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
+    "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
+    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
+    "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
+    "Disable video" : "ვიდეოს გათიშვა",
+    "Share screen" : "ეკრანის გაზიარება",
+    "Show your screen" : "თქვენი ეკრანის ჩვენება",
+    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
+    "No Camera" : "კამერა არაა",
+    "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
+    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
+    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
+    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
+    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
+    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
+    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
     "moderator" : "მოდერატორი",
     "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
     "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
     "Remove participant" : "მონაწილის ამოშლა",
-    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
-    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
-    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
     "Close" : "დახურვა",
-    "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
-    "Disable video" : "ვიდეოს გათიშვა",
     "Show screen" : "ეკრანის ჩვენება",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
     "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
     "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
-    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
     "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
-    "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
     "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
     "Guest's screen" : "სტუმრის ეკრანი",
     "Your screen" : "თქვენი ეკრანი",
@@ -104,38 +104,8 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
     "TURN server" : "TURN სერვერი",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
-    "Video calls" : "ვიდეო ზარები",
     "(group)" : "(ჯგუფი)",
-    "New public call" : "ახალი ღია ზარი",
-    "Looking great today! :)" : "დღეს კარგად გამოიყურებით! :)",
-    "Time to call your friends" : "დროა დაურეკოთ თქვენს მეგობრებს",
-    "You can set your name on the top right of this page so other participants can identify you better." : "გვერდის ზედა მარჯვენა მხარეს შეგიძლიათ დააყენოთ სახელი, მონაწილეები უკეთ ამოგიცნობენ.",
-    "This call has ended" : "ეს ზარი დასრულდა",
-    "Saving failed" : "შენახვა ვერ მოხერხდა",
-    "Add person" : "დაამატეთ პიროვნება",
     "and you" : "და თქვენ",
-    "Please adjust your configuration" : "გთხოვთ დაარეგულიროთ თქვენი პარამეტრები",
-    "{actor} invited you to a private call" : "პირად ზარზე მოწვევა მომხმარებლისგან {actor}",
-    "{actor} invited you to a group call" : "ჯგუფურ ზარზე მოწვევა მომხმარებლისგან {actor}",
-    "{actor} invited you to the call {call}" : "{call} ზარზე მოწვევა მომხმარებლისგან {actor}",
-    "You were invited to a <strong>video call</strong>" : "თქვენ მოგიწვიეს <strong>ვიდეო ზარზე</strong>",
-    "Video call" : "ვიდეო ზარი",
-    "Invalid format, must be stunserver:port." : "არასწორი ფორმატი უნდა იყოს stunserver:port.",
-    "Invalid port specified." : "სპეციფირებულია არასწორი პორტი.",
-    "Invalid protocols specified." : "სპეციფირებულია არასწორი პროტოკოლები.",
-    "%s invited you to a private call" : "%s მოხმარებლის მოწვევა პირად ზარზე",
-    "{user} invited you to a private call" : "{user} მომხმარებლის მოწვევა პირად ზარზე",
-    "%s invited you to a group call: %s" : "%s მომხმარებლის მოწვევა ჯგუფურ ზარზე: %s",
-    "{user} invited you to a group call: {call}" : "{user} მომხმარებლის მოწვევა ჯგუფურ ზარზე: {call}",
-    "%s invited you to a group call" : "%s მომხმარებლის მოწვევა ჯგუფურ ზარზე",
-    "{user} invited you to a group call" : "{user} მომხმარებლის მოწვევა ჯგუფურ ზარზე",
-    "Fullscreen" : "მთელი ეკრანი",
-    "Mute audio" : "ხმის ჩახშობა",
-    "Smile in 3… 2… 1!" : "გაიღიმეთ 3... 2... 1!",
-    "Choose person …" : "აირჩიეთ პიროვნება ...",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "მონაწილეების ზარზე დასაკავშირებლად აუცილებელია STUN სერვერი. TURN სერვერი კავშირს უზრუნველყოფს ფაირვოლის გამოყენების შემთხვევაშიც.",
-    "STUN server" : "STUN სერვერი",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
     "… %s" : "… %s",
     "%s …" : "%s … ",
     "… %s …" : "... %s ..."
