@@ -13,27 +13,12 @@ OC.L10N.register(
     "New public conversation" : "Naujas viešas pokalbis",
     "New group conversation" : "Naujas grupės pokalbis",
     "New conversation …" : "Naujas pokalbis …",
-    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
-    "Screensharing options" : "Ekrano bendrinimo parinktys",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
-    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
-    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
-    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
-    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
     "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
     "Fullscreen (f)" : "Visas ekranas (f)",
-    "Mute audio (m)" : "Nutildyti garsą (m)",
-    "Disable video (v)" : "Išjungti vaizdą (v)",
-    "Enable video (v)" : "Įjungti vaizdą (v)",
-    "Enable screensharing" : "Įjungti ekrano bendrinimą",
     "Copy" : "Kopijuoti",
     "Copied!" : "Nukopijuota!",
     "Not supported!" : "Nepalaikoma!",
     "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
-    "Show your screen" : "Rodyti savo ekraną",
-    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
     "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
     "Password required" : "Reikalingas slaptažodis",
     "Password" : "Slaptažodis",
@@ -57,30 +42,50 @@ OC.L10N.register(
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
+    "Waiting for {participantName} to join the call …" : "Laukiama kol {participantName} prisijungs prie skambučio …",
+    "Waiting for others to join the call …" : "Laukiama kol kiti prisijungs prie skambučio …",
+    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
+    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
+    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
+    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
+    "Disable video" : "Išjungti vaizdą",
+    "Show your screen" : "Rodyti savo ekraną",
+    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
+    "Mute audio (m)" : "Nutildyti garsą (m)",
+    "Enable video (v)" : "Įjungti vaizdą (v)",
+    "Disable video (v)" : "Išjungti vaizdą (v)",
+    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
+    "Screensharing options" : "Ekrano bendrinimo parinktys",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
+    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
+    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
+    "Enable screensharing" : "Įjungti ekrano bendrinimą",
     "moderator" : "moderatorius",
     "Remove participant" : "Šalinti dalyvį",
     "Add participant …" : "Pridėti dalyvį …",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
     "Delete conversation" : "Ištrinti pokalbį",
-    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
     "Close" : "Užverti",
-    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
-    "Disable video" : "Išjungti vaizdą",
     "Show screen" : "Rodyti ekraną",
     "Enable video" : "Įjungti vaizdą",
     "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
     "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo atmesta",
     "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
-    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
     "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
-    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
     "Guest's screen" : "Svečio ekranas",
     "Your screen" : "Jūsų ekranas",
     "(Duration %s)" : "(Trukmė %s)",
     "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečių"],
     "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
+    "You removed the password" : "Jūs pašalinote slaptažodį",
+    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
+    "You added {user}" : "Jūs pridėjote naudotoją {user}",
+    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
+    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
     "%s (guest)" : "%s (svečias)",
     "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
     ", " : ", ",
@@ -99,25 +104,7 @@ OC.L10N.register(
     "TURN server" : "TURN serveris",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
-    "Video calls" : "Vaizdo skambučiai",
     "(group)" : "(grupė)",
-    "Looking great today! :)" : "Šiandien puikiai atrodote! :)",
-    "Time to call your friends" : "Metas paskambinti savo draugams",
-    "Saving failed" : "Įrašymas nepavyko",
-    "Please adjust your configuration" : "Suderinkite savo konfigūraciją",
-    "{actor} invited you to a private call" : "{actor} pakvietė jus į privatų skambutį",
-    "{actor} invited you to the call {call}" : "{actor} pakvietė jus į skambutį {call}",
-    "You were invited to a <strong>video call</strong>" : "Jūs buvote pakviesti į <strong>vaizdo skambutį</strong>",
-    "Video call" : "Vaizdo skambutis",
-    "Invalid format, must be stunserver:port." : "Neteisingas formatas, privalo būti stunserveris:prievadas.",
-    "Invalid port specified." : "Nurodytas neteisingas prievadas.",
-    "Invalid protocols specified." : "Nurodyti neteisingi prievadai.",
-    "%s invited you to a private call" : "%s pakvietė jus į privatų skambutį",
-    "{user} invited you to a private call" : "{user} pakvietė jus į privatų skambutį",
-    "Fullscreen" : "Visas ekranas",
-    "Mute audio" : "Nutildyti garsą",
-    "Smile in 3… 2… 1!" : "Šypsokitės po 3… 2… 1!",
-    "STUN server" : "STUN serveris",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …",
