@@ -17,36 +17,16 @@ OC.L10N.register(
     "New public conversation" : "Ny offentlig samtale",
     "New group conversation" : "Ny gruppesamtale",
     "New conversation …" : "Ny samtale…",
-    "Screensharing is not supported by your browser." : "Skjermdeling støttes ikke av din nettleser.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
-    "Screensharing options" : "Skjermdelingsvalg",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
-    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
-    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
     "Participants" : "Deltakere",
     "Chat" : "Sludre",
     "Talk" : "Samtale",
-    "Waiting for {participantName} to join the call …" : "Venter på at {participantName} skal bli med i samtalen…",
-    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
     "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
     "Fullscreen (f)" : "Fullskjermsvisning (f)",
-    "Mute audio (m)" : "Slå av lyd (m)",
-    "Unmute audio (m)" : "Slå på lyd (m)",
-    "No audio" : "Ingen lyd",
-    "Disable video (v)" : "Skru av video (v)",
-    "Enable video (v)" : "Skru på video (v)",
-    "No Camera" : "Inget kamera",
-    "Enable screensharing" : "Skru på skjermdeling",
     "Copy" : "Kopier",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikke støttet!",
     "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
     "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
-    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
-    "Share screen" : "Del skjerm",
-    "Show your screen" : "Vis din skjerm",
-    "Stop screensharing" : "Stopp skjermdeling",
     "Please enter the password for this call" : "Skriv inn passordet for denne samtalen",
     "Password required" : "Passord kreves",
     "Password" : "Passord",
@@ -75,28 +55,48 @@ OC.L10N.register(
     "{relativeDate}, {absoluteDate}" : "{relativData}, {abosluttData}",
     "Error occurred while sending message" : "Feil oppstod under foresendelse av melding",
     "Edit" : "Rediger",
+    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
+    "No other people in this call" : "Ingen andre personer i denne samtalen",
+    "Waiting for {participantName} to join the call …" : "Venter på at {participantName} skal bli med i samtalen…",
+    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
+    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
+    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC støttes ikke av din nettleser :-/",
+    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
+    "Waiting for camera and microphone permissions" : "Venter på kamera- og mikrofon-tilganger",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Gi nettleseren tilgang til å bruke kamera og mikrofon for å kunne bruke dette programmet.",
+    "Disable video" : "Skru av video",
+    "Share screen" : "Del skjerm",
+    "Show your screen" : "Vis din skjerm",
+    "Stop screensharing" : "Stopp skjermdeling",
+    "Unmute audio (m)" : "Slå på lyd (m)",
+    "Mute audio (m)" : "Slå av lyd (m)",
+    "No audio" : "Ingen lyd",
+    "Enable video (v)" : "Skru på video (v)",
+    "Disable video (v)" : "Skru av video (v)",
+    "No Camera" : "Inget kamera",
+    "Screensharing is not supported by your browser." : "Skjermdeling støttes ikke av din nettleser.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
+    "Screensharing options" : "Skjermdelingsvalg",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
+    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
+    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
+    "Enable screensharing" : "Skru på skjermdeling",
     "moderator" : "moderator",
     "Demote from moderator" : "Fjern moderatorstatus",
     "Promote to moderator" : "Gi moderatorstatus",
     "Remove participant" : "Fjern deltaker",
     "Add participant …" : "Legg til deltager…",
     "Delete conversation" : "Slett samtale",
-    "No other people in this call" : "Ingen andre personer i denne samtalen",
-    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
-    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
     "Close" : "Lukk",
-    "Waiting for camera and microphone permissions" : "Venter på kamera- og mikrofon-tilganger",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Gi nettleseren tilgang til å bruke kamera og mikrofon for å kunne bruke dette programmet.",
-    "Disable video" : "Skru av video",
     "Show screen" : "Vis skjerm",
     "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
     "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
     "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
     "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
-    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
     "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
-    "WebRTC is not supported in your browser :-/" : "WebRTC støttes ikke av din nettleser :-/",
     "{participantName}'s screen" : "{participantName}'s skjerm",
     "Guest's screen" : "Gjestens skjerm",
     "Your screen" : "Din skjerm",
@@ -124,38 +124,8 @@ OC.L10N.register(
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-tjener brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
     "TURN server" : "TURN-tjener",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-tjeneren fungerer som mellomtjener for trafikk fra deltakere bak en brannmur.",
-    "Video calls" : "Videosamtaler",
     "(group)" : "(gruppe)",
-    "New public call" : "Ny offentlig samtale",
-    "Looking great today! :)" : "Ser bra ut i dag! :)",
-    "Time to call your friends" : "På tide å ringe dine venner",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Du kan sette navnet ditt øverst til høyre på siden slik at andre deltagere har lettere for å identifisere deg.",
-    "This call has ended" : "Denne samtalen er avsluttet",
-    "Saving failed" : "Lagring mislyktes",
-    "Add person" : "Legg til person",
     "and you" : "og deg",
-    "Please adjust your configuration" : "Juster oppsettet ditt",
-    "{actor} invited you to a private call" : "{actor} inviterte deg til en privat samtale",
-    "{actor} invited you to a group call" : "{actor} inviterte deg til gruppesamtale",
-    "{actor} invited you to the call {call}" : "{actor} inviterte deg til samtalen {call}",
-    "You were invited to a <strong>video call</strong>" : "Du ble invitert til en <strong>videosamtale</strong>",
-    "Video call" : "Videosamtale",
-    "Invalid format, must be stunserver:port." : "Ugyldig format, må være stunserver:port.",
-    "Invalid port specified." : "Ugyldig port angitt.",
-    "Invalid protocols specified." : "Ugyldig protokoll angitt.",
-    "%s invited you to a private call" : "%s inviterte deg til privat samtale",
-    "{user} invited you to a private call" : "{user} inviterte deg til privat samtale",
-    "%s invited you to a group call: %s" : "%s inviterte deg til en gruppesamtale: %s",
-    "{user} invited you to a group call: {call}" : "{user} inviterte deg til å ta del i en gruppesamtale: {call}",
-    "%s invited you to a group call" : "%s inviterte deg til gruppesamtale",
-    "{user} invited you to a group call" : "{user} inviterte deg til gruppesamtale",
-    "Fullscreen" : "Fullskjerm",
-    "Mute audio" : "Slå av lyd",
-    "Smile in 3… 2… 1!" : "Smil i 3… 2… 1!",
-    "Choose person …" : "Velg person…",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN- tjeneren er nødvendig for at deltakere kan koble til samtaler. TURN- tjeneren sørger for at koblingen fungerer selv gjennom brannmurer.",
-    "STUN server" : "STUN-tjener",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN-tjeneren brukes til å bestemme offentlig IP-adresse til deltagere bak en ruter.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …"
