@@ -5,6 +5,7 @@ OC.L10N.register(
     "Delete server" : "Ta bort server",
     "Add new server" : "Lägg till ny server",
     "Saved" : "Sparad",
+    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du raderade alla STUN-servrar. Eftersom det nästan alltid behövs har en standard STUN-server lagts till.",
     "Shared secret" : "Delad hemlighet",
     "TURN server shared secret" : "TURN server delade hemlighet",
     "UDP and TCP" : "UDP och TCP",
@@ -15,39 +16,22 @@ OC.L10N.register(
     "New group conversation" : "Ny gruppkonversation",
     "{name} (public)" : "{name} (publik)",
     "New conversation …" : "Ny konversation",
-    "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
-    "Screensharing options" : "Skärmdelningsalternativ",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
-    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
-    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
     "Participants" : "Deltagare",
     "Chat" : "Chat",
     "Talk" : "Talk",
-    "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
-    "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
     "Fullscreen (f)" : "Fullskärm (f)",
-    "Mute audio (m)" : "Ljud av (m)",
-    "Unmute audio (m)" : "Ljud på (m)",
-    "No audio" : "Inget ljud",
-    "Disable video (v)" : "Inaktivera video (v)",
-    "Enable video (v)" : "Aktivera video (v)",
     "Set your name in the chat window so other participants can identify you better." : "Ange ditt namn i chattfönstret så andra deltagare kan identifiera dig bättre. ",
-    "No Camera" : "Ingen kamera",
-    "Enable screensharing" : "Tillåt skärmdelning",
     "Copy" : "Kopiera",
     "Copied!" : "Kopierat!",
     "Not supported!" : "Ej kompatibel!",
     "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
     "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
-    "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
-    "This conversation has ended" : "Denna konversation har avslutats",
+    "Error while getting the room ID" : "Fel vid mottagande av rum-ID",
+    "Start a conversation" : "Starta en konversation",
+    "Share this file with others to discuss" : "Dela den här filen med andra att diskutera",
+    "Share" : "Dela",
     "Request password" : "Begär lösenord",
-    "Share screen" : "Dela skärm",
-    "Show your screen" : "Visa din skärm",
-    "Stop screensharing" : "Stoppa skärmdelning",
     "Error requesting the password." : "Fel vid begäran av lösenord.",
     "Please enter the password for this call" : "Var god ange lösenordet för detta samtal",
     "Password required" : "Lösenord krävs",
@@ -71,7 +55,6 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
     "New message …" : "Nytt meddelande",
     "Send" : "Skicka",
-    "Share" : "Dela",
     "Guest" : "Gäst",
     "[Unknown user name]" : "[Okänt användarnam]",
     "Today" : "Idag",
@@ -82,6 +65,40 @@ OC.L10N.register(
     "File to share" : "Fil att dela",
     "Error while sharing" : "Fel vid delning",
     "Edit" : "Ändra",
+    "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
+    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
+    "No other people in this call" : "Inga andra personer i detta samtal",
+    "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
+    "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
+    "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
+    "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
+    "WebRTC is not supported in your browser :-/" : "WebRTC är inte kompatibelt med din webbläsare :-/",
+    "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
+    "Waiting for camera and microphone permissions" : "Väntar på godkännande att använda kamera och mikrofon",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vänligen ge din webbläsare tillåtelse att använda din kamera och mikrofon för att kunna använda denna funktion.",
+    "This conversation has ended" : "Denna konversation har avslutats",
+    "Mute audio" : "Stäng av ljudet",
+    "Disable video" : "Stäng av video",
+    "Share screen" : "Dela skärm",
+    "Share whole screen" : "Dela hela skärmen",
+    "Share a single window" : "Dela ett fönster",
+    "Show your screen" : "Visa din skärm",
+    "Stop screensharing" : "Stoppa skärmdelning",
+    "Unmute audio (m)" : "Ljud på (m)",
+    "Mute audio (m)" : "Ljud av (m)",
+    "No audio" : "Inget ljud",
+    "Enable video (v)" : "Aktivera video (v)",
+    "Disable video (v)" : "Inaktivera video (v)",
+    "No Camera" : "Ingen kamera",
+    "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
+    "Screensharing options" : "Skärmdelningsalternativ",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
+    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
+    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
+    "Enable screensharing" : "Tillåt skärmdelning",
     "moderator" : "moderator",
     "Demote from moderator" : "Degradera från moderator",
     "Promote to moderator" : "Befordra till moderator",
@@ -98,22 +115,13 @@ OC.L10N.register(
     "Never notify" : "Meddela aldrig",
     "Leave conversation" : "Lämna konversationen",
     "Delete conversation" : "Radera konversationen",
-    "No other people in this call" : "Inga andra personer i detta samtal",
-    "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
-    "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
     "Close" : "Stäng",
-    "Waiting for camera and microphone permissions" : "Väntar på godkännande att använda kamera och mikrofon",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vänligen ge din webbläsare tillåtelse att använda din kamera och mikrofon för att kunna använda denna funktion.",
-    "Disable video" : "Stäng av video",
     "Show screen" : "Visa skärm",
     "Enable video" : "Aktivera video",
     "Access to microphone & camera is only possible with HTTPS" : "Tillgång till mikrofon och kamera är endast möjligt via HTTPS",
     "Access to microphone & camera was denied" : "Tillgång till mikrofon och kamera blev nekad",
     "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
-    "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
     "Error while accessing microphone & camera" : "Kunde ej ansluta mikrofon och kamera",
-    "WebRTC is not supported in your browser :-/" : "WebRTC är inte kompatibelt med din webbläsare :-/",
     "{participantName}'s screen" : "{participantName}'s skärm",
     "Guest's screen" : "Gästskärm",
     "Your screen" : "Din skärm",
@@ -147,8 +155,11 @@ OC.L10N.register(
     "{actor} removed the password" : "{actor} tog bort lösenordet",
     "You removed the password" : "Du tog bort lösenordet",
     "{actor} added {user}" : "{actor} la till {user}",
+    "You joined the conversation" : "Du gick med i konversationen",
+    "{actor} joined the conversation" : "{actor} gick med i konversationen",
     "You added {user}" : "Du la till {user}",
     "{actor} added you" : "{actor} la till dig",
+    "You left the conversation" : "Du lämnade konversationen",
     "{actor} left the conversation" : "{actor} lämnade konversationen",
     "{actor} removed {user}" : "{actor} tog bort {user}",
     "You removed {user}" : "Du tog bort {user}",
@@ -167,6 +178,8 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
     "Talk to %s" : "Prata med %s",
+    "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
+    "Password request: %s" : "Lösenordsförfrågan: %s",
     "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
     ", " : ",",
     "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
@@ -198,6 +211,8 @@ OC.L10N.register(
     "{user} wants to talk with you" : "{user} vill prata med dig",
     "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
     "A group call has started" : "Ett gruppsamtal har startats",
+    "{email} requested the password to access {file}" : "{email} begärde lösenordet för åtkomst till {file}",
+    "Someone requested the password to access {file}" : "Någon begärde lösenordet för att komma åt {file}",
     "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
     "Conversation not found" : "Konversationen hittades inte",
     "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
@@ -214,38 +229,8 @@ OC.L10N.register(
     "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
-    "Video calls" : "Videosamtal",
     "(group)" : " (grupp)",
-    "New public call" : "Nytt offentligt samtal",
-    "Looking great today! :)" : "Du ser bra ut idag! :)",
-    "Time to call your friends" : "Dags att ringa dina vänner",
-    "You can set your name on the top right of this page so other participants can identify you better." : "Du kan ändra ditt namn upp till höger på denna sida så att de andra deltagarna kan se vem du är.",
-    "This call has ended" : "Samtalet avslutades",
-    "Saving failed" : "Lyckades ej att spara",
-    "Add person" : "Lägg till person",
     "and you" : "och du",
-    "Please adjust your configuration" : "Vänligen justera dina inställningar",
-    "{actor} invited you to a private call" : "{actor} bjöd in dig till ett privat samtal",
-    "{actor} invited you to a group call" : "{actor} bjöd in dig till ett gruppsamtal",
-    "{actor} invited you to the call {call}" : "{actor} bjöd in dig till samtalet {call}",
-    "You were invited to a <strong>video call</strong>" : "Du blev inbjuden till ett <strong>videosamtal</strong>",
-    "Video call" : "Videosamtal",
-    "Invalid format, must be stunserver:port." : "Ogiltigt format, måste skrivas stunserver:port.",
-    "Invalid port specified." : "Ogiltig port angivet.",
-    "Invalid protocols specified." : "Ogiltigt protokoll angivet.",
-    "%s invited you to a private call" : "%s har bjudit in dig till ett privat samtal",
-    "{user} invited you to a private call" : "{user} har bjudit in dig till ett privat samtal",
-    "%s invited you to a group call: %s" : "%s bjöd in dig till ett gruppsamtal: %s",
-    "{user} invited you to a group call: {call}" : "{user} bjöd in dig till ett gruppsamtal: {call}",
-    "%s invited you to a group call" : "%s har bjudit in dig till ett gruppsamtal",
-    "{user} invited you to a group call" : "{user} har bjudit in dig till ett gruppsamtal",
-    "Fullscreen" : "Helskärm",
-    "Mute audio" : "Stäng av ljud",
-    "Smile in 3… 2… 1!" : "Le om 3... 2... 1!",
-    "Choose person …" : "Välj person ...",
-    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "STUN-servern krävs för att deltagare kan ansluta till samtal. TURN-servern säkerställer att anslutningar fungerar genom brandväggar.",
-    "STUN server" : "STUN server",
-    "The STUN server is used to determine the public IP address of participants behind a router." : "STUN-servern används för att bestämma den publika IP-adressen av deltagare bakom en router.",
     "… %s" : "… %s",
     "%s …" : "%s …",
     "… %s …" : "… %s …",
