@@ -45,6 +45,8 @@ class Capabilities implements IPublicCapability {
 					'system-messages',
 					'mention-flag',
 					'in-call-flags',
+					'notification-levels',
+					'invite-groups-and-mails',
 				],
 			],
 		];
