@@ -121,7 +121,7 @@ class Manager {
 			$lastMention = new \DateTime($row['last_mention']);
 		}
 
-		return new Participant($this->db, $room, (string) $row['user_id'], (int) $row['participant_type'], (int) $row['last_ping'], (string) $row['session_id'], (int) $row['in_call'], (bool) $row['favorite'], $lastMention);
+		return new Participant($this->db, $room, (string) $row['user_id'], (int) $row['participant_type'], (int) $row['last_ping'], (string) $row['session_id'], (int) $row['in_call'], (int) $row['notification_level'], (bool) $row['favorite'], $lastMention);
 	}
 
 	/**
@@ -298,6 +298,30 @@ class Manager {
 		return $this->createRoomObject($row);
 	}
 
+	/**
+	 * @param string $objectType
+	 * @param string $objectId
+	 * @return Room
+	 * @throws RoomNotFoundException
+	 */
+	public function getRoomByObject(string $objectType, string $objectId): Room {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from('talk_rooms')
+			->where($query->expr()->eq('object_type', $query->createNamedParameter($objectType)))
+			->andWhere($query->expr()->eq('object_id', $query->createNamedParameter($objectId)));
+
+		$result = $query->execute();
+		$row = $result->fetch();
+		$result->closeCursor();
+
+		if ($row === false) {
+			throw new RoomNotFoundException();
+		}
+
+		return $this->createRoomObject($row);
+	}
+
 	/**
 	 * @param string|null $userId
 	 * @param string $sessionId
