@@ -1,7 +1,8 @@
 <?php
 /** @var array $_ */
 /** @var \OCP\IL10N $l */
-script('spreed', ['admin/turn-server']);
+script('spreed', ['admin/turn-server', 'admin/templates']);
+script('spreed', ['admin/sha1']);
 style('spreed', ['settings-admin']);
 ?>
 
